@@ -3,31 +3,31 @@
 -- =========================
 
 function lutius(title, text)
-   return speech("map:Lutius.png", "2F9131", title, text)
+   return speech("map:Lutius.png", styles.color("campaign_emp_lutius"), title, text)
 end
 function saledus2(title, text)
-   return speech("map:Saledus2.png", "8F9131", title, text)
+   return speech("map:Saledus2.png", styles.color("campaign_emp_saledus"), title, text)
 end
 function saledus3(title, text)
-   return speech("map:Saledus3.png", "8F9131", title, text)
+   return speech("map:Saledus3.png", styles.color("campaign_emp_saledus"), title, text)
 end
 function saledus4(title, text)
-   return speech("map:Saledus2.png", "8F9131", title, text)
+   return speech("map:Saledus2.png", styles.color("campaign_emp_saledus"), title, text)
 end
 function amalea1(title, text)
-   return speech("map:Amalea.png", "AF7511", title, text)
+   return speech("map:Amalea.png", styles.color("campaign_emp_amalea"), title, text)
 end
 function amalea2(title, text)
-   return speech("map:Amalea2.png", "AF7511", title, text)
+   return speech("map:Amalea2.png", styles.color("campaign_emp_amalea"), title, text)
 end
 function amalea3(title, text)
-   return speech("map:Amalea3.png", "AF7511", title, text)
+   return speech("map:Amalea3.png", styles.color("campaign_emp_amalea"), title, text)
 end
 function julia(title, text)
-   return speech("map:Julia.png", "D0D0D0", title, text)
+   return speech("map:Julia.png", styles.color("campaign_emp_julia"), title, text)
 end
 function marcus(title, text)
-   return speech("map:Markus.png", "1175AF", title, text)
+   return speech("map:Markus.png", styles.color("campaign_emp_marcus"), title, text)
 end
 
 
@@ -40,157 +40,157 @@ end
 -- ===========
 obj_dismantle_buildings = {
    name = "dismantle_unproductive_buildings",
-   title=_"Dismantle the unproductive buildings",
+   title=_("Dismantle the unproductive buildings"),
    number = 1,
-   body = objective_text(_"Dismantle Buildings",
-      li(_[[Dismantle all unproductive small buildings to get some resources for new buildings.]]) ..
-      li_arrow(_[[Remember to check the messages and the building statistics for unproductive buildings.]])
+   body = objective_text(_("Dismantle Buildings"),
+      li(_([[Dismantle all unproductive small buildings to get some resources for new buildings.]])) ..
+      li_arrow(_([[Remember to check the messages and the building status labels for unproductive buildings.]]))
    ),
 }
 
 obj_clear_roads = {
    name = "clear_roads",
-   title=_"Clear all unnecessary roads",
+   title=_("Clear all unnecessary roads"),
    number = 1,
-   body = objective_text(_"Clear Road Network",
-      li(_[[Resolve the chaotic road network by clearing all unnecessary roads.]])
+   body = objective_text(_("Clear Road Network"),
+      li(_([[Resolve the chaotic road network by clearing all unnecessary roads.]]))
    ),
 }
 
-obj_clear_roads_hint = rt(objective_text(_"Clear Road Network",
-   li(_[[Resolve the chaotic road network by clearing all unnecessary roads.]]) ..
-   li_arrow(_[[Ensure there are not more than 3 dead ends, nor more than one flag with more than 4 roads.]])
+obj_clear_roads_hint = rt(objective_text(_("Clear Road Network"),
+   li(_([[Resolve the chaotic road network by clearing all unnecessary roads.]])) ..
+   li_arrow(_([[Ensure there are not more than 3 dead ends, nor more than one flag with more than 4 roads.]]))
    ))
 
 obj_click_farmbuilding = {
    name = "click_farm_building",
-   title=_"Click on one of the farms",
+   title=_("Click on one of the farms"),
    number = 1,
-   body = objective_text(_"Open the Building Window of a Farm",
-      li(_[[Click on a farm building to open its building window. This will let you analyze the building.]])
+   body = objective_text(_("Open the Building Window of a Farm"),
+      li(_([[Click on a farm building to open its building window. This will let you analyze the building.]]))
    ),
 }
 
 obj_find_farm_plans = {
    name = "find_farm_construction_plans",
-   title=_"Find the construction plans for the farms",
+   title=_("Find the construction plans for the farms"),
    number = 1,
-   body = objective_text(_"Find Farm Construction Plans",
-      li(_[[Recover the construction plans for the farms. Search for them in the hills east of your border.]])
+   body = objective_text(_("Find Farm Construction Plans"),
+      li(_([[Recover the construction plans for the farms. Search for them in the hills east of your border.]]))
    ),
 }
 
 obj_build_quarries_and_lumberjacks = {
    name = "build_quarries_and_lumberjacks",
-   title=_"Build at least 3 lumberjack’s houses and 2 quarries",
+   title=_("Build at least 3 lumberjack’s houses and 2 quarries"),
    number = 1,
-   body = objective_text(_"Quarries and Lumberjacks",
-      li(_[[Build at least three lumberjack’s houses and two quarries to renew your building material supply chain.]])
+   body = objective_text(_("Quarries and Lumberjacks"),
+      li(_([[Build at least three lumberjack’s houses and two quarries to renew your building material supply chain.]]))
    ),
 }
 
 obj_produce_fish = {
    name = "produce_fish",
-   title=_"Produce fish and rations",
+   title=_("Produce fish and rations"),
    number = 1,
-   body = objective_text(_"Food Production",
-      li(_[[Find and catch some fish. Afterwards, produce rations for your miners.]])
+   body = objective_text(_("Food Production"),
+      li(_([[Find and catch some fish. Afterwards, produce rations for your miners.]]))
    ),
 }
 
 obj_replace_foresters = {
    name = "replace_foresters",
-   title=_"Replace the old and ineffective forester’s houses",
+   title=_("Replace the old and ineffective forester’s houses"),
    number = 1,
-   body = objective_text(_"Build Two New Forester’s Houses",
-      li(_[[Replace the two forester’s houses by new ones to increase productivity.]])
+   body = objective_text(_("Build Two New Forester’s Houses"),
+      li(_([[Replace the two forester’s houses by new ones to increase productivity.]]))
    ),
 }
 
 obj_find_monastery = {
    name = "find_monastery",
-   title=_"Find the monastery in the north",
+   title=_("Find the monastery in the north"),
    number = 1,
-   body = objective_text(_"Find the Monastery",
-      li(_[[Find the monastery in the north to obtain the improved technology for your wheat production chain.]])
+   body = objective_text(_("Find the Monastery"),
+      li(_([[Find the monastery in the north to obtain the improved technology for your wheat production chain.]]))
    ),
 }
 
 obj_deal_with_julia = {
    name = "deal_with_julia",
-   title=_"Deal with Julia to get the technology",
+   title=_("Deal with Julia to get the technology"),
    number = 1,
-   body = objective_text(_"Diplomacy: Trade or War",
-      li(_[[Decide: Either collect 35 sheaves of wheat and 15 amphoras of wine for the goddess in your headquarters or conquer the monastery.]])
+   body = objective_text(_("Diplomacy: Trade or War"),
+      li(_([[Decide: Either collect 35 sheaves of wheat and 15 amphoras of wine for the goddess in your headquarters or conquer the monastery.]]))
    ),
 }
 
 obj_heroes = {
    name = "train_heroes",
-   title=_"Train at least 3 heroes",
+   title=_("Train at least 3 heroes"),
    number = 1,
-   body = objective_text(_"Hero Training",
-      li(_[[Use your resources wisely to train at least three fully promoted heroes.]]) ..
-      li_arrow(_[[To train a soldier to the highest level in one site, consider stopping the trainingsite until it is fully equipped with all food and weapons needed.]]) ..
-      li_arrow(_[[To prevent waste of goods, reduce the soldiers to be trained to one per site.]]) ..
-      li_arrow(_[[A site will always prefer the best suited soldier available for training. Make sure you don’t have your half trained soldiers garrisoned in a military building.]])
+   body = objective_text(_("Hero Training"),
+      li(_([[Use your resources wisely to train at least three fully promoted heroes.]])) ..
+      li_arrow(_([[To train a soldier to the highest level in one site, consider stopping the trainingsite until it is fully equipped with all food and weapons needed.]])) ..
+      li_arrow(_([[To prevent waste of goods, reduce the soldiers to be trained to one per site.]])) ..
+      li_arrow(_([[A site will always prefer the best suited soldier available for training. Make sure you don’t have your half trained soldiers garrisoned in a military building.]]))
    ),
 }
 
 obj_produce_tools = {
    name = "produce_tools",
-   title=_"Produce at least 10 tools",
+   title=_("Produce at least 10 tools"),
    number = 1,
-   body = objective_text(_"Tool Production",
-      li(_[[Produce at least ten tools to improve your economy.]]) ..
-      li_arrow(_[[Remember that you can control the production amount in the economy settings.]])
+   body = objective_text(_("Tool Production"),
+      li(_([[Produce at least ten tools to improve your economy.]])) ..
+      li_arrow(_([[Remember that you can control the production amount in the economy settings.]]))
    ),
 }
 
 obj_recruit_soldiers = {
    name = "recruit_soldiers",
-   title=_"Recruit new soldiers",
+   title=_("Recruit new soldiers"),
    number = 1,
-   body = objective_text(_"New Soldier Recruiting",
-      li(_[[Recruit at least ten new soldiers in your barracks.]])
+   body = objective_text(_("New Soldier Recruiting"),
+      li(_([[Recruit at least ten new soldiers in your barracks.]]))
    ),
 }
 
 obj_conquer_all = {
    name = "conquer_all",
-   title=_"Defeat the Barbarians",
+   title=_("Defeat the Barbarians"),
    number = 1,
-   body = objective_text(_"Defeat the Enemy",
-      li(_[[End the Barbarian intrusion into your very own part of the world.]])
+   body = objective_text(_("Defeat the Enemy"),
+      li(_([[End the Barbarian intrusion into your very own part of the world.]]))
    ),
 }
 
 obj_charcoal = {
    name = "charcoal",
-   title=_"Build 2 charcoal kilns",
+   title=_("Build 2 charcoal kilns"),
    number = 1,
-   body = objective_text(_"Build Two Charcoal Kilns",
-      li(_[[Build two charcoal kilns to support the iron industry.]]) ..
-      li_arrow(_[[Remember to ensure a constant log supply for them.]])
+   body = objective_text(_("Build Two Charcoal Kilns"),
+      li(_([[Build two charcoal kilns to support the iron industry.]])) ..
+      li_arrow(_([[Remember to ensure a constant log supply for them.]]))
    ),
 }
 
 obj_training = {
    name = "train_your_soldiers",
-   title=_"Increase your military strength by training your soldiers",
+   title=_("Increase your military strength by training your soldiers"),
    number = 1,
-   body = objective_text(_"Training is Important",
-      li(_[[Train your soldiers hard and train them fast.]]) ..
-      li_arrow(_[[You need to increase your military strength.]])
+   body = objective_text(_("Training is Important"),
+      li(_([[Train your soldiers hard and train them fast.]])) ..
+      li_arrow(_([[You need to increase your military strength.]]))
    ),
 }
 
 obj_upgrade = {
    name = "upgrade",
-   title=_"Build a training camp and enhance the arena",
+   title=_("Build a training camp and enhance the arena"),
    number = 1,
-   body = objective_text(_"More Efficient Training Buildings",
-      li(_[[Build a training camp and enhance your arena to a colosseum.]])
+   body = objective_text(_("More Efficient Training Buildings"),
+      li(_([[Build a training camp and enhance your arena to a colosseum.]]))
    ),
 }
 
@@ -201,8 +201,8 @@ obj_upgrade = {
 -- Diary of Lutius
 
 diary_page_1 = {
-   title =_"Home, Sweet Home",
-   body=lutius(_"Diary of Lutius",
+   title =_("Home, Sweet Home"),
+   body=lutius(_("Diary of Lutius"),
       -- TRANSLATORS: Lutius - Diary
       _([[Finally, we managed to reach home. I am so glad to see our beautiful country again. I am really looking forward to a walk on our lovely coast and to hunting in our deep forests.]])
       .. paragraphdivider() ..
@@ -212,53 +212,54 @@ diary_page_1 = {
 }
 
 diary_page_2= {
-   title=_"Tools, Tools, Tools",
-   body= lutius(_"Diary of Lutius",
+   title=_("Tools, Tools, Tools"),
+   body= lutius(_("Diary of Lutius"),
       -- TRANSLATORS: Lutius - Diary
       _([[Praise the gods! We just ensured a constant tool supply. Now we should be able to expand our economy.]])),
    posy=1,
 }
 
 diary_page_3= {
-   title=_"Military Strength",
-   body= lutius(_"Diary of Lutius",
+   title=_("Military Strength"),
+   body= lutius(_("Diary of Lutius"),
       -- TRANSLATORS: Lutius - Diary
       _([[Thank the gods! Now we have everything prepared to fully train our soldiers. We can increase our military strength at last.]])),
    posy=1,
 }
 
 diary_page_4 = {
-   title=_"The Battle is Won",
-   body= lutius(_"Diary of Lutius",
+   title=_("The Battle is Won"),
+   body= lutius(_("Diary of Lutius"),
       -- TRANSLATORS: Lutius - Diary
       _([[Praise the gods, we have succeeded. We managed all the challenges that were imposed on us. We even expelled the Barbarians out of our country. However, our victory is only temporary, as this is still just the beginning of the war. Let’s see what the future still holds for us.]]))
-      .. objective_text(_"Victory",
-      _[[You have completed this mission. You may continue playing if you wish, otherwise move on to the next mission.]]),
+      .. objective_text(_("Victory"),
+      _([[You have completed this mission. You may continue playing if you wish, otherwise move on to the next mission.]])),
    posy=1,
+   allow_next_scenario = true,
 }
 
 
 -- Lutius
 
 lutius_1 = {
-   title=_"Chaos",
-   body= lutius(_"Lutius is disappointed",
+   title=_("Chaos"),
+   body= lutius(_("Lutius is disappointed"),
       -- TRANSLATORS: Lutius
       _([[Oh no! Amalea is right. In fact, I can’t see any productivity at all. And the road network seems to be completely in shambles as well. Who might be responsible for this chaos?]])),
    posy=1,
 }
 
 lutius_2 = {
-   title=_"Explanation Needed",
-   body= lutius(_"Lutius greets the official",
+   title=_("Explanation Needed"),
+   body= lutius(_("Lutius greets the official"),
       -- TRANSLATORS: Lutius
       _([[Ave! Who are you and what happened to our beautiful land?]])),
    posy=1,
 }
 
 lutius_3 = {
-   title=_"Difficult Times",
-   body= lutius(_"Lutius accepts the challenge",
+   title=_("Difficult Times"),
+   body= lutius(_("Lutius accepts the challenge"),
       -- TRANSLATORS: Lutius
       _([[Mayor, we have to thank you for your efforts to safeguard our city. And we will do our very best to recover from the chaos. But unfortunately, this seems to be very difficult.]])
       .. paragraphdivider() ..
@@ -271,8 +272,8 @@ lutius_3 = {
 -- Marcus (mayor of Fremil)
 
 marcus_1 = {
-   title=_"Welcome Back",
-   body= marcus(_"A high Fremil official is welcoming you…",
+   title=_("Welcome Back"),
+   body= marcus(_("A high Fremil official is welcoming you…"),
       -- TRANSLATORS: Marcus - Mayor of Fremil welcoming Lutius and explaining the chaos
       _([[Ave, Sire! The people and me are so glad to see you returning back home. We really need some good leadership around here.]])
       .. paragraphdivider() ..
@@ -281,8 +282,8 @@ marcus_1 = {
 }
 
 marcus_2 = {
-   title=_"A Long Story",
-   body= marcus(_"The official sighs deeply…",
+   title=_("A Long Story"),
+   body= marcus(_("The official sighs deeply…"),
       -- TRANSLATORS: Marcus - Mayor of Fremil welcoming Lutius and explaining the chaos
       _([[Sire, let me start from the beginning. The king left Fremil a long time ago to fight the Barbarians. As this duty was demanding his full commitment, he delegated the authority of running the city to his former secretary and instated him as his surrogate around here.]])
       .. paragraphdivider() ..
@@ -296,8 +297,8 @@ marcus_2 = {
 -- Amalea
 
 amalea = {
-   title=_"Amalea Looks Puzzled",
-   body= amalea1(_"Amalea is doubtful…",
+   title=_("Amalea Looks Puzzled"),
+   body= amalea1(_("Amalea is doubtful…"),
       -- TRANSLATORS: Amalea
       _([[Ave, Saledus! On the one hand you are right, it really is a delight to see our homeland again. But on the other hand, I have the impression that something went deeply wrong here.]])
       .. paragraphdivider() ..
@@ -307,8 +308,8 @@ amalea = {
 }
 
 amalea_1 = {
-   title=_"Amalea Investigates",
-   body= amalea2(_"Amalea is nodding thoughtfully…",
+   title=_("Amalea Investigates"),
+   body= amalea2(_("Amalea is nodding thoughtfully…"),
       -- TRANSLATORS: Amalea
       _([[Lutius, in my opinion this will again be a very difficult challenge. But I’m afraid that we’re doomed to manage this situation. To make things even worse, I was met with a nasty surprise at our warehouses: they’re all empty. You can hardly find a grain of dust left in there: no wares, no tools, no workers and no soldiers either.]])
       .. paragraphdivider() ..
@@ -326,8 +327,8 @@ amalea_1 = {
 }
 
 amalea_2 = {
-   title=_"Amalea has Bad News",
-   body= amalea3(_"Amalea recommends…",
+   title=_("Amalea has Bad News"),
+   body= amalea3(_("Amalea recommends…"),
       -- TRANSLATORS: Amalea
       _([[Brother, I’m really worried that I have to deliver bad news again. As you can see, our farms aren’t producing anything and we can’t dismantle them.]])
       .. paragraphdivider() ..
@@ -345,8 +346,8 @@ amalea_2 = {
 }
 
 amalea_3 = {
-   title=_"Amalea Looks Confident",
-   body= amalea2(_"Amalea is more confident",
+   title=_("Amalea Looks Confident"),
+   body= amalea2(_("Amalea is more confident"),
       -- TRANSLATORS: Amalea
       _([[Lutius, now we are getting somewhere. As we have gained some construction materials, we can start to rebuild our economy.]])
       .. paragraphdivider() ..
@@ -361,8 +362,8 @@ amalea_3 = {
 }
 
 amalea_4 = {
-   title=_"Amalea is Somewhat Relieved",
-   body= amalea2(_"Amalea is giving a deep sigh…",
+   title=_("Amalea is Somewhat Relieved"),
+   body= amalea2(_("Amalea is giving a deep sigh…"),
       -- TRANSLATORS: Amalea
       _([[Praise the gods, Lutius! We have found the plans on how to build and operate farms.]])
       .. paragraphdivider() ..
@@ -376,8 +377,8 @@ amalea_4 = {
 }
 
 amalea_5 = {
-   title=_"Amalea has Good News",
-   body= amalea2(_"Amalea smiles for the first time in weeks…",
+   title=_("Amalea has Good News"),
+   body= amalea2(_("Amalea smiles for the first time in weeks…"),
       -- TRANSLATORS: Amalea
       _([[Lutius, well done so far. I just got the news that we have finished the basic buildings to obtain some construction materials.]])
       .. paragraphdivider() ..
@@ -398,8 +399,8 @@ amalea_5 = {
 }
 
 amalea_6 = {
-   title=_"Amalea is Pleased",
-   body= amalea3(_"Amalea is nodding her head…",
+   title=_("Amalea is Pleased"),
+   body= amalea3(_("Amalea is nodding her head…"),
       -- TRANSLATORS: Amalea
       _([[Well done, well done. Our road network looks a lot more structured than before.]])
       .. paragraphdivider() ..
@@ -410,8 +411,8 @@ amalea_6 = {
 }
 
 amalea_7 = {
-   title=_"Amalea Shakes Her Head",
-   body= amalea2(_"Amalea is getting fed up with all the problems in this economy…",
+   title=_("Amalea Shakes Her Head"),
+   body= amalea2(_("Amalea is getting fed up with all the problems in this economy…"),
       -- TRANSLATORS: Amalea
       _([[For the sake of Neptune, I just discovered another problem! It seems that really very few things are working as expected in this economy.]])
       .. paragraphdivider() ..
@@ -429,8 +430,8 @@ amalea_7 = {
 }
 
 amalea_8 = {
-   title=_"Amalea Laughs Sarcastically",
-   body= amalea1(_"Amalea is laughing sarcastically…",
+   title=_("Amalea Laughs Sarcastically"),
+   body= amalea1(_("Amalea is laughing sarcastically…"),
       -- TRANSLATORS: Amalea
       _([[Well, Lutius, we have just solved another weird behavior in our economy. Now our lumberjacks should be supplied with enough trees to enhance our economy.]])
       .. paragraphdivider() ..
@@ -440,8 +441,8 @@ amalea_8 = {
 }
 
 amalea_9 = {
-   title=_"Amalea Shrugs",
-   body= amalea3(_"Amalea is getting used to bad news…",
+   title=_("Amalea Shrugs"),
+   body= amalea3(_("Amalea is getting used to bad news…"),
       -- TRANSLATORS: Amalea
       _([[Alright Lutius, here is another problem: after the production of some beer and some flour, I realized that the technology that we are using in our mills and breweries is somewhat outdated. This way, they are consuming far too many resources.]])
       .. paragraphdivider() ..
@@ -456,8 +457,8 @@ amalea_9 = {
 }
 
 amalea_10 = {
-   title=_"Amalea Looks Happy",
-   body= amalea2(_"Amalea comes in…",
+   title=_("Amalea Looks Happy"),
+   body= amalea2(_("Amalea comes in…"),
       -- TRANSLATORS: Amalea
       _([[Brother, I think this is a rather fair offer. And some good will from any of our gods could be very helpful as well.]])
       .. paragraphdivider() ..
@@ -468,8 +469,8 @@ amalea_10 = {
 
 
 amalea_11 = {
-   title=_"Amalea Looks Sad",
-   body= amalea1(_"Amalea is really sad…",
+   title=_("Amalea Looks Sad"),
+   body= amalea1(_("Amalea is really sad…"),
       -- TRANSLATORS: Amalea
       _([[I’m not sure if that was the right thing to do. Yes, we have obtained the plans. But although we are now able to build and upgrade our mills and breweries with the improved technology, we will never know if and how Vesta and her priestesses could have helped us against the Barbarians.]])
       .. paragraphdivider() ..
@@ -479,8 +480,8 @@ amalea_11 = {
 }
 
 amalea_12 = {
-   title=_"Amalea is Very Content",
-   body= amalea2(_"Amalea claps her hands…",
+   title=_("Amalea is Very Content"),
+   body= amalea2(_("Amalea claps her hands…"),
       -- TRANSLATORS: Amalea
       _([[Well done. Now we are able to build more efficient buildings to refine our wheat. Furthermore, the plans enable us to upgrade our current mill and brewery with the improved technology.]])
       .. paragraphdivider() ..
@@ -490,8 +491,8 @@ amalea_12 = {
 }
 
 amalea_13 = {
-   title=_"Amalea is Satisfied",
-   body= amalea3(_"Amalea is satisfied with the progress…",
+   title=_("Amalea is Satisfied"),
+   body= amalea3(_("Amalea is satisfied with the progress…"),
       -- TRANSLATORS: Amalea
       _([[Alright Lutius, another problem solved. Still more to come. As we are able to produce food now, we should start mining some coal and iron ore immediately. After all, we need more tools to get our economy back up and build more and different production sites.]])
       .. paragraphdivider() ..
@@ -506,8 +507,8 @@ amalea_13 = {
 }
 
 amalea_14 = {
-   title=_"Amalea has Some Advice",
-   body= amalea3(_"Amalea is providing economic advice…",
+   title=_("Amalea has Some Advice"),
+   body= amalea3(_("Amalea is providing economic advice…"),
       -- TRANSLATORS: Amalea
       _([[Lutius, it seems that our coal supply is a little weak. So, we need to expand and explore all mineable areas for more coal.]])
       .. paragraphdivider() ..
@@ -519,32 +520,32 @@ amalea_14 = {
 }
 
 amalea_15 = {
-   title=_"Amalea is in a Good Mood",
-   body= amalea2(_"Amalea is celebrating success…",
+   title=_("Amalea is in a Good Mood"),
+   body= amalea2(_("Amalea is celebrating success…"),
       -- TRANSLATORS: Amalea
       _([[Great, another issue solved! Now the charcoal will support our metal production and we can concentrate more on exploration and military strength.]])),
    posy=1,
 }
 
 amalea_16 = {
-   title=_"Amalea Looks Thoughtful",
-   body= amalea2(_"Amalea is sorrowful…",
+   title=_("Amalea Looks Thoughtful"),
+   body= amalea2(_("Amalea is sorrowful…"),
       -- TRANSLATORS: Amalea
       _([[Dear brother, I have bad news to report. One of our buildings has just been destroyed by an uncontrolled kitchen fire. I fear this might be a sign of the goddess Vesta still being in a bad mood.]])),
    posy=1,
 }
 
 amalea_17 = {
-   title=_"Amalea is Positively Surprised",
-   body= amalea2(_"Amalea is celebrating a happy event…",
+   title=_("Amalea is Positively Surprised"),
+   body= amalea2(_("Amalea is celebrating a happy event…"),
       -- TRANSLATORS: Amalea
       _([[Cheers Lutius, I don’t know how, but we have been gifted with some beer and wine. We found the additional wares while we were taking stock recently. Maybe the goddess Vesta is still supporting us.]])),
    posy=1,
 }
 
 amalea_18 = {
-   title=_"Amalea Analyzes the Economy",
-   body= amalea1(_"Amalea reminds Lutius of the farms…",
+   title=_("Amalea Analyzes the Economy"),
+   body= amalea1(_("Amalea reminds Lutius of the farms…"),
       -- TRANSLATORS: Amalea
       _([[Look Lutius, I have just analyzed our economy somewhat further. I think there might be a problem with our farms. They don’t show any productivity although there is enough space to plant wheat.]])
       .. paragraphdivider() ..
@@ -556,8 +557,8 @@ amalea_18 = {
 }
 
 amalea_19 = {
-   title=_"Amalea’s Restrictions",
-   body= amalea1(_"Amalea restricts the building possibilities…",
+   title=_("Amalea’s Restrictions"),
+   body= amalea1(_("Amalea restricts the building possibilities…"),
       -- TRANSLATORS: Amalea
       _([[Excuse me Lutius, but I think the most critical resources in the current state of our economy are logs.]])
       .. paragraphdivider() ..
@@ -567,8 +568,8 @@ amalea_19 = {
 }
 
 amalea_20 = {
-   title=_"Amalea Reminds to Clear Road Network",
-   body= amalea3(_"Amalea reminds Lutius of the scrambled road network…",
+   title=_("Amalea Reminds to Clear Road Network"),
+   body= amalea3(_("Amalea reminds Lutius of the scrambled road network…"),
       -- TRANSLATORS: Amalea
       _([[Look Brother, I have just realized we haven’t cleared the road network yet. I think we should do so very quickly to free enough space for new buildings.]])
       .. paragraphdivider() ..
@@ -578,16 +579,16 @@ amalea_20 = {
 }
 
 amalea_21 = {
-   title=_"Defeated!",
-   body= amalea2(_"Amalea reports our defeat…",
+   title=_("Defeated!"),
+   body= amalea2(_("Amalea reports our defeat…"),
       -- TRANSLATORS: Amalea
       _([[Oh no Lutius, I don’t know how this could have happened, but the Barbarians have sacked our headquarters. So, we have lost this battle and our empire!]])),
    posy=1,
 }
 
 amalea_22 = {
-   title=_"Amalea has Bad News",
-   body= amalea2(_"Amalea reports our headquarters lost…",
+   title=_("Amalea has Bad News"),
+   body= amalea2(_("Amalea reports our headquarters lost…"),
       -- TRANSLATORS: Amalea
       _([[Oh no Lutius, I don’t know how this could have happened, but the Barbarians have destroyed our headquarters. So, we can’t deliver the wares to Julia anymore.]])
       .. paragraphdivider() ..
@@ -597,16 +598,16 @@ amalea_22 = {
 }
 
 amalea_23 = {
-   title=_"Defeated!",
-   body= amalea2(_"Amalea reports our defeat…",
+   title=_("Defeated!"),
+   body= amalea2(_("Amalea reports our defeat…"),
       -- TRANSLATORS: Amalea
       _([[Oh no Lutius, I don’t know how this could have happened, but the Barbarians have destroyed our last warehouse. So, we have lost this battle and our empire!]])),
    posy=1,
 }
 
 amalea_24 = {
-   title=_"Amalea in a Hurry",
-   body= amalea1(_"Amalea is very busy…",
+   title=_("Amalea in a Hurry"),
+   body= amalea1(_("Amalea is very busy…"),
       -- TRANSLATORS: Amalea
       _([[Brother, as you can see, a lot of things seem to be wrong in this economy. I’ll be very busy to examine everything, so I won’t be here to provide as detailed advice as I used to do.]])
       .. paragraphdivider() ..
@@ -618,16 +619,16 @@ amalea_24 = {
 -- Saledus
 
 saledus = {
-   title=_"Military Strength",
-   body= saledus2(_"Saledus looks very relaxed…",
+   title=_("Military Strength"),
+   body= saledus2(_("Saledus looks very relaxed…"),
       -- TRANSLATORS: Saledus
       _([[Sire, it is really a great pleasure to be at home again. And best of all: I can see we still have some military strength. I can count five towers and a fortress in our vicinity to guard us.]])),
    posy=1,
 }
 
 saledus_1 = {
-   title=_"We Could Use The Military Instead",
-   body= saledus2(_"Saledus raises his voice…",
+   title=_("We Could Use The Military Instead"),
+   body= saledus2(_("Saledus raises his voice…"),
       -- TRANSLATORS: Saledus
       _([[Sire, if we need the technology that badly, why don’t we conquer it? We could defeat the little monastery in an instant.]])
       .. paragraphdivider() ..
@@ -639,24 +640,24 @@ saledus_1 = {
 }
 
 saledus_2 = {
-   title=_"Easy Victory",
-   body= saledus3(_"Saledus is cheering proudly…",
+   title=_("Easy Victory"),
+   body= saledus3(_("Saledus is cheering proudly…"),
       -- TRANSLATORS: Saledus
       _([[General, our armies just swept over the priestesses and conquered the plans. That was a rather easy victory.]])),
    posy=1,
 }
 
 saledus_3 = {
-   title=_"Defiance",
-   body= saledus2(_"Saledus asserts his point…",
+   title=_("Defiance"),
+   body= saledus2(_("Saledus asserts his point…"),
       -- TRANSLATORS: Saledus
       _([[Sire, I admit this has been proven to be a very good deal, although we could have had the plans much earlier. Anyhow, we will not be able to make any deals with the Barbarians, so, we better keep our soldiers in a good mood and train them adequately.]])),
    posy=1,
 }
 
 saledus_4 = {
-   title=_"Pride",
-   body= saledus2(_"Saledus asserts his point…",
+   title=_("Pride"),
+   body= saledus2(_("Saledus asserts his point…"),
       -- TRANSLATORS: Saledus
       _([[Sire, I admit that we most probably courted the gods’ resentment, but in wartime, the end will sometimes justify the means. And we won’t be able to make any deals with the Barbarians either, so, we better keep our soldiers in good mood and train them adequately.]])),
    posy=1,
@@ -664,8 +665,8 @@ saledus_4 = {
 
 
 saledus_5 = {
-   title=_"Military Strength",
-   body= saledus2(_"Saledus asks for a stronger army…",
+   title=_("Military Strength"),
+   body= saledus2(_("Saledus asks for a stronger army…"),
       -- TRANSLATORS: Saledus
       _([[Now that we have produced some tools, I think it is time to divert some of our iron and coal towards military production.]])
       .. paragraphdivider() ..
@@ -680,8 +681,8 @@ saledus_5 = {
 }
 
 saledus_6 = {
-   title=_"Training is Needed",
-   body= saledus3(_"Saledus still has security concerns…",
+   title=_("Training is Needed"),
+   body= saledus3(_("Saledus still has security concerns…"),
       -- TRANSLATORS: Saledus
       _([[General, although we have started recruiting new soldiers, we still need to train them well. It is important to increase the strength of our soldiers as fast as we can.]])
       .. paragraphdivider() ..
@@ -692,8 +693,8 @@ saledus_6 = {
 }
 
 saledus_7 = {
-   title=_"Praise The Army of The Empire",
-   body= saledus2(_"Saledus is happy…",
+   title=_("Praise The Army of The Empire"),
+   body= saledus2(_("Saledus is happy…"),
       -- TRANSLATORS: Saledus
       _([[Sire, after training a bunch of recruits, our trainers conferred with our builders and developed better and more efficient training buildings together.]])
       .. paragraphdivider() ..
@@ -704,8 +705,8 @@ saledus_7 = {
 }
 
 saledus_8 = {
-   title=_"We Just Need Another Hero",
-   body= saledus4(_"Saledus is in a good mood…",
+   title=_("We Just Need Another Hero"),
+   body= saledus4(_("Saledus is in a good mood…"),
       -- TRANSLATORS: Saledus
       _([[General, now that we have more and better beer in addition to enhanced training facilities, we should train as many fully promoted soldiers as we can. I really would consider them heroes after that.]])
       .. paragraphdivider() ..
@@ -718,8 +719,8 @@ saledus_8 = {
 }
 
 saledus_9 = {
-   title=_"We Should Expel The Barbarians",
-   body= saledus3(_"Saledus is excited…",
+   title=_("We Should Expel The Barbarians"),
+   body= saledus3(_("Saledus is excited…"),
       -- TRANSLATORS: Saledus
       _([[Now that we have some fully trained soldiers, it is time to expel the Barbarians from our homeland.]])
       .. paragraphdivider() ..
@@ -730,8 +731,8 @@ saledus_9 = {
 }
 
 saledus_10 = {
-   title=_"Victory is Ours",
-   body= saledus2(_"Saledus is cheering loudly…",
+   title=_("Victory is Ours"),
+   body= saledus2(_("Saledus is cheering loudly…"),
       -- TRANSLATORS: Saledus
       _([[Sire, finally we have defeated the Barbarians. We have expelled even the last of them. May they never come back!]])
       .. paragraphdivider() ..
@@ -740,8 +741,8 @@ saledus_10 = {
 }
 
 saledus_11 = {
-   title=_"The Enemy is Near",
-   body= saledus3(_"Saledus is alerted…",
+   title=_("The Enemy is Near"),
+   body= saledus3(_("Saledus is alerted…"),
       -- TRANSLATORS: Saledus
       _([[Sire, although we don’t have enough fully trained soldiers yet, we just have made contact with the enemy.]])
       .. paragraphdivider() ..
@@ -756,24 +757,24 @@ saledus_11 = {
 -- Julia - priestess of the goddess Vesta
 
 julia_0 = {
-   title=_"Worship to be Gifted",
-   body= julia(_"Julia is demanding a sacrifice for Vesta…",
+   title=_("Worship to be Gifted"),
+   body= julia(_("Julia is demanding a sacrifice for Vesta…"),
       -- TRANSLATORS: Julia - priestess of the goddess Vesta
       _([[Ave, Lutius! If you want us to help you, you first have to worship our goddess Vesta. Therefore deliver 35 sheaves of wheat and 15 amphoras of wine to prepare a worthy sacrifice for her.]])),
    posy=1,
 }
 
 julia_1 = {
-   title=_"May The Gods Bless You",
-   body= julia(_"Vesta is blessing us…",
+   title=_("May The Gods Bless You"),
+   body= julia(_("Vesta is blessing us…"),
       -- TRANSLATORS: Julia - priestess of the goddess Vesta
       _([[Thank you Lutius, you have served our goddess well. You will not only be gifted with the improvements to your technology but with some of the goods you need so desperately as well. Furthermore, we will pray for you and join your party to safeguard our land from the Barbarians.]])),
    posy=1,
 }
 
 julia_2 = {
-   title=_"Damned",
-   body= julia(_"Vesta is cursing us…",
+   title=_("Damned"),
+   body= julia(_("Vesta is cursing us…"),
       -- TRANSLATORS: Julia - priestess of the goddess Vesta
       _([[Damn you Lutius for killing peaceful servants of the goddess Vesta! May your life and your land be cursed and may the wrath of the goddess scourge your family from the face of the earth!]])),
    posy=1,
