@@ -1,8 +1,8 @@
-dirname = "tribes/buildings/productionsites/empire/well/"
+local dirname = "campaigns/emp04.wmf/" .. path.dirname (__file__)
 
 push_textdomain("scenario_emp04.wmf")
 
-descriptions:new_productionsite_type {
+wl.Descriptions():new_productionsite_type {
    name = "empire_well1",
    descname = pgettext("empire_building", "Well"),
    icon = dirname .. "menu.png",
@@ -18,14 +18,14 @@ descriptions:new_productionsite_type {
       marble = 1,
    },
 
+   animation_directory = dirname,
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 43, 43 },
+         hotspot = { 39, 57 },
       },
       working = {
-         pictures = path.list_files(dirname .. "idle_??.png"), -- TODO(GunChleoc): No animation yet.
-         hotspot = { 43, 43 },
+         basename = "idle", -- TODO(hessenfarmer): No animation yet.
+         hotspot = { 39, 57 },
       },
    },
 
@@ -49,9 +49,9 @@ descriptions:new_productionsite_type {
       },
    },
    out_of_resource_notification = {
-      title = "No Water",
-      heading = "Out of Water",
-      message = "The carrier working at this well can’t find any water in his well.",
+      title = pgettext("empire_building", "No Water"),
+      heading = pgettext("empire_building", "Out of Water"),
+      message = pgettext("empire_building", "The carrier working at this well can’t find any water in his well."),
       productivity_threshold = 15
    },
 }
