@@ -16,36 +16,43 @@ local wc_name = "Collectors"
 -- will be used as the key to fetch the translation in C++
 local wc_descname = _("Collectors")
 local wc_version = 2
-local wc_desc = _ (
+local wc_desc_placeholder = _(
    "You get points for precious wares in your warehouses. The player with " ..
-   "the highest number of wares at the end of 4 hours wins the game."
+   "the highest score after %s wins the game."
 )
+-- TRANSLATORS: Will be inserted into "The player with the highest score after %s wins the game."
+local wc_desc = wc_desc_placeholder:bformat(_("the configured time limit"))
 local wc_points = "Points"
 -- This needs to be exactly like wc_points, but localized, because wc_points
 -- will be used as the key to fetch the translation in C++
-local wc_points_i18n = _"Points"
+local wc_points_i18n = _("Points")
 local r = {
    name = wc_name,
    description = wc_desc,
+   configurable_time = true,
    peaceful_mode_allowed = true,
    func = function()
 
-   -- set the objective with the game type for all players
-   broadcast_objective("win_condition", wc_descname, wc_desc)
+   local game = wl.Game()
 
    -- set the maximum game time of 4 hours
-   local max_time = 4 * 60
+   local max_time = game.win_condition_duration
+
+   -- set the objective with the game type for all players
+   broadcast_objective("win_condition", wc_descname, wc_desc_placeholder:bformat(format_remaining_raw_time(max_time)))
 
-   local game = wl.Game()
    local plrs = wl.Game().players
+   local function _gather_teams(plrs)
    local teams = {}
-   for idx,plr in ipairs(plrs) do
-      if (plr.team ~= 0) then
-         if (teams[plr.team] == nil) then
-            teams[plr.team] = {}
+      for idx,plr in ipairs(plrs) do
+         if (plr.team ~= 0) then
+            if (teams[plr.team] == nil) then
+               teams[plr.team] = {}
+            end
+            table.insert(teams[plr.team], plr)
          end
-         table.insert(teams[plr.team], plr)
       end
+      return teams
    end
 
    -- Calculate the momentary points for a list of players
@@ -62,7 +69,7 @@ local r = {
             end
          end
 
-         descr = descr .. h2((_"Status for %s"):format(plr.name))
+         descr = descr .. h2((_("Status for %s")):format(plr.name))
          local points = 0
          for idx,pair in ipairs(plr.tribe.collectors_points_table) do
             local count = 0
@@ -74,7 +81,7 @@ local r = {
 
             local warename = wl.Game():get_ware_description(pair.ware).descname
             -- TRANSLATORS: For example: 'gold (3 P) x 4 = 12 P', P meaning 'Points'
-            descr = descr .. li(_"%1$s (%2$i P) x %3$i = %4$i P"):bformat(
+            descr = descr .. li(_("%1$s (%2$i P) x %3$i = %4$i P")):bformat(
                warename, pair.points, count, lpoints
             )
          end
@@ -88,23 +95,23 @@ local r = {
 
    -- Send all players the momentary game state
    local function _send_state(remaining_time, plrs, show_popup)
-      local msg = format_remaining_time(remaining_time) .. vspace(8) .. game_status.body
+      local msg = format_remaining_time(remaining_time) .. msg_vspace() .. game_status.body
 
       -- Points for players without team
       for idx, plr in ipairs(plrs) do
          if (plr.team == 0) then
             local points, pstat = _calc_points({plr})
-            msg = msg .. vspace(8) .. pstat
+            msg = msg .. msg_vspace() .. pstat
          end
       end
       -- Team points
       push_textdomain("win_conditions")
-      for idx, team in ipairs(teams) do
+      for idx, team in ipairs(_gather_teams(plrs)) do
          local points, pstat = _calc_points(team)
-         local message = h1((_"Status for Team %d"):format(idx))
+         local message = h1((_("Status for Team %d")):format(idx))
             .. pstat
             .. h2(ngettext("Team Total: %i point", "Team Total: %i points", points)):format(points)
-         msg = msg .. vspace(8) .. message
+         msg = msg .. msg_vspace() .. message
       end
       pop_textdomain()
 
@@ -114,6 +121,7 @@ local r = {
    local function _game_over(plrs)
       local points = {}
       local win_points = 0
+      local teams = _gather_teams(plrs)
       for idx,plr in ipairs(plrs) do
          local player_points, pstat = _calc_points({plr})
          if (plr.team == 0) then
