@@ -15,18 +15,22 @@ local wc_name = "Wood Gnome"
 -- will be used as the key to fetch the translation in C++
 local wc_descname = _("Wood Gnome")
 local wc_version = 2
-local wc_desc = _(
+local wc_desc_placeholder = _(
 [[As wood gnome you like big forests, so your task is to have more trees on ]] ..
-[[your territory than any other player. The game will end after 4 hours of ]] ..
-[[playing. The one with the most trees at that point will win the game.]])
+[[your territory than any other player. The game will end after %s. ]] ..
+[[The one with the most trees at that point will win the game.]])
+-- TRANSLATORS: Will be inserted into "The game will end after %s."
+local wc_desc = wc_desc_placeholder:bformat(_("the configured time limit"))
+
 local wc_trees_owned = "Trees owned"
 -- This needs to be exactly like wc_trees_owned, but localized, because wc_trees_owned
 -- will be used as the key to fetch the translation in C++
-local wc_trees_owned_i18n = _"Trees owned"
+local wc_trees_owned_i18n = _("Trees owned")
 
 local r = {
    name = wc_name,
    description = wc_desc,
+   configurable_time = true,
    peaceful_mode_allowed = true,
    init = function()
       -- Calculate valuable fields
@@ -37,10 +41,10 @@ local r = {
    local game = wl.Game()
 
    -- set the maximum game time of 4 hours
-   local max_time = 4 * 60
+   local max_time = game.win_condition_duration
 
    -- set the objective with the game type for all players
-   broadcast_objective("win_condition", wc_descname, wc_desc)
+   broadcast_objective("win_condition", wc_descname, wc_desc_placeholder:bformat(format_remaining_raw_time(max_time)))
 
    -- The function to calculate the current points.
    local _last_time_calculated = -100000
@@ -57,14 +61,14 @@ local r = {
 
    local function _send_state(remaining_time, plrs, show_popup)
       _calc_points()
-      local msg = format_remaining_time(remaining_time) .. vspace(8) .. game_status.body
+      local msg = format_remaining_time(remaining_time) .. msg_vspace() .. game_status.body
 
       push_textdomain("win_conditions")
       for idx,plr in ipairs(plrs) do
          local trees = (ngettext ("%i tree", "%i trees", playerpoints[plr.number]))
                :format(playerpoints[plr.number])
          -- TRANSLATORS: %1$s = player name, %2$s = x tree(s)
-         msg = msg .. p(_"%1$s has %2$s at the moment."):bformat(plr.name,trees)
+         msg = msg .. p(_("%1$s has %2$s at the moment.")):bformat(plr.name,trees)
       end
       pop_textdomain()
 
@@ -80,32 +84,39 @@ local r = {
       table.sort(points, function(a,b) return a[2] < b[2] end)
 
       push_textdomain("win_conditions")
-      local msg = vspace(8) .. game_status.body
+      local msg = msg_vspace() .. game_status.body
       for idx,plr in ipairs(plrs) do
-         msg = msg .. vspace(8)
+         msg = msg .. msg_vspace()
          local trees = (ngettext ("%i tree", "%i trees", playerpoints[plr.number])):format(playerpoints[plr.number])
          -- TRANSLATORS: %1$s = player name, %2$s = x tree(s)
-         msg = msg ..  p(_"%1$s had %2$s."):bformat(plr.name,trees)
+         msg = msg ..  p(_("%1$s had %2$s.")):bformat(plr.name,trees)
+      end
+      msg = msg .. msg_vspace()
+      local trees = (ngettext ("%i tree", "%i trees", points[#points][2])):format(points[#points][2])
+      if #points == 1 or points[#points][2] ~= points[#points - 1][2] then -- one winner
+         -- TRANSLATORS: %1$s = player name, %2$s = x tree(s)
+         msg = msg ..  h3(_("The winner is %1$s with %2$s.")):bformat(points[#points][1].name, trees)
+      else
+         -- TRANSLATORS: %s = x tree(s)
+         msg = msg .. h3(_("The winners had %s.")):bformat(trees)
+         -- TODO maybe, create list of winners and show as %$1s: The winners are %$1s with %$2s.
       end
-      msg = msg .. vspace(8)
-      local trees = (ngettext ("%i tree", "%i trees", playerpoints[points[#points][1].number]))
-            :format(playerpoints[points[#points][1].number])
-      -- TRANSLATORS: %1$s = player name, %2$s = x tree(s)
-      msg = msg ..  h3(_"The winner is %1$s with %2$s."):bformat(points[#points][1].name, trees)
       pop_textdomain()
 
+      local win_points = points[#points][2] -- points of winner(s)
       local privmsg = ""
-      for i=1,#points-1 do
-         privmsg = lost_game_over.body
+      for i=1,#points do
+         local win_lost = 0
+         local end_msgs = lost_game_over
+         if points[i][2] >= win_points then
+            end_msgs = won_game_over
+            win_lost = 1
+         end
+         privmsg = end_msgs.body
          privmsg = privmsg .. msg
-         points[i][1]:send_to_inbox(lost_game_over.title, privmsg)
-         wl.game.report_result(points[i][1], 0, make_extra_data(points[i][1], wc_descname, wc_version, {score=points[i][2]}))
+         points[i][1]:send_to_inbox(end_msgs.title, privmsg)
+         wl.game.report_result(points[i][1], win_lost, make_extra_data(points[i][1], wc_descname, wc_version, {score=points[i][2]}))
       end
-      privmsg = won_game_over.body
-      privmsg = privmsg .. msg
-      points[#points][1]:send_to_inbox(won_game_over.title, privmsg)
-      wl.game.report_result(points[#points][1], 1,
-         make_extra_data(points[#points][1], wc_descname, wc_version, {score=points[#points][2]}))
    end
 
    -- Install statistics hook
