@@ -1,11 +1,12 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_productionsite_type {
+wl.Descriptions():new_productionsite_type {
    name = "amazons_jungle_preservers_hut",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("amazons_building", "Jungle Preserver’s Hut"),
+   animation_directory = dirname,
    icon = dirname .. "menu.png",
    size = "small",
 
@@ -19,8 +20,6 @@ descriptions:new_productionsite_type {
 
    spritesheets = {
       idle = {
-         directory = dirname,
-         basename = "idle",
          hotspot = {50, 46},
          fps = 4,
          frames = 4,
@@ -30,8 +29,6 @@ descriptions:new_productionsite_type {
    },
    animations = {
       unoccupied = {
-         directory = dirname,
-         basename = "unoccupied",
          hotspot = {39, 46}
       }
    },
@@ -48,8 +45,12 @@ descriptions:new_productionsite_type {
    programs = {
       main = {
          -- TRANSLATORS: Completed/Skipped/Did not start planting trees because ...
-         descname = _"planting trees",
+         descname = _("planting trees"),
          actions = {
+            -- time of worker: 11.2-36.4 sec, mean 24.088 sec
+            -- min. time total: 11.2 + 9 = 20.2 sec
+            -- max. time total: 36.4 + 9 = 45.4 sec
+            -- mean time total: 24.088 + 9 = 33.088 sec
             "callworker=plant",
             "sleep=duration:9s"
          }
