@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_productionsite_type {
+wl.Descriptions():new_productionsite_type {
    name = "atlanteans_fishers_house",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("atlanteans_building", "Fisher’s House"),
@@ -17,10 +17,10 @@ descriptions:new_productionsite_type {
       planks = 1
    },
 
+   animation_directory = dirname,
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 34, 42 },
+         hotspot = { 40, 50 },
       },
    },
 
@@ -39,8 +39,12 @@ descriptions:new_productionsite_type {
    programs = {
       main = {
          -- TRANSLATORS: Completed/Skipped/Did not start fishing because ...
-         descname = _"fishing",
+         descname = _("fishing"),
          actions = {
+            -- time of worker: 16.7-45.5 sec, min+max average 31.1 sec
+            -- min. time total: 16.7 + 9.5 = 26.2 sec
+            -- max. time total: 45.5 + 9.5 = 55 sec
+            -- avg. time total: 31.1 + 9.5 = 40.6 sec
             "callworker=fish",
             "sleep=duration:9s500ms"
          }
@@ -49,8 +53,8 @@ descriptions:new_productionsite_type {
    },
    out_of_resource_notification = {
       -- Translators: Short for "Out of ..." for a resource
-      title = _"No Fish",
-      heading = _"Out of Fish",
+      title = _("No Fish"),
+      heading = _("Out of Fish"),
       message = pgettext("atlanteans_building", "The fisher working out of this fisher’s house can’t find any fish in his work area. Remember that you can increase the number of existing fish by building a fish breeder’s house."),
    },
 }
