@@ -1,11 +1,11 @@
-dirname = path.dirname(__file__)
+push_textdomain("tribes")
 
-tribes:new_productionsite_type {
-   msgctxt = "atlanteans_building",
+local dirname = path.dirname(__file__)
+
+wl.Descriptions():new_productionsite_type {
    name = "atlanteans_gold_spinning_mill",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("atlanteans_building", "Gold Spinning Mill"),
-   helptext_script = dirname .. "helptexts.lua",
    icon = dirname .. "menu.png",
    size = "small",
 
@@ -19,14 +19,14 @@ tribes:new_productionsite_type {
       granite = 1
    },
 
+   animation_directory = dirname,
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 33, 64 },
+         hotspot = { 34, 74 },
       },
       working = {
-         pictures = path.list_files(dirname .. "idle_??.png"), -- TODO(GunChleoc): No animation yet.
-         hotspot = { 33, 64 },
+         basename = "idle", -- TODO(GunChleoc): No animation yet.
+         hotspot = { 34, 74 },
       }
    },
 
@@ -41,22 +41,21 @@ tribes:new_productionsite_type {
    inputs = {
       { name = "gold", amount = 5 }
    },
-   outputs = {
-      "gold_thread"
-   },
 
    programs = {
-      work = {
+      main = {
          -- TRANSLATORS: Completed/Skipped/Did not start spinning gold because ...
-         descname = _"spinning gold",
+         descname = _("spinning gold"),
          actions = {
             "return=skipped unless economy needs gold_thread",
             "consume=gold",
-            "sleep=15000",
-            "playsound=sound/atlanteans/goldspin 192",
-            "animate=working 25000",
+            "sleep=duration:15s",
+            "playsound=sound/atlanteans/goldspin priority:50% allow_multiple",
+            "animate=working duration:25s",
             "produce=gold_thread"
          }
       },
    },
 }
+
+pop_textdomain()
