@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_productionsite_type {
+wl.Descriptions():new_productionsite_type {
    name = "atlanteans_smokery",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("atlanteans_building", "Smokery"),
@@ -19,16 +19,22 @@ descriptions:new_productionsite_type {
       granite = 3
    },
 
+   animation_directory = dirname,
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 53, 58 },
+         hotspot = { 54, 74 },
       },
+
+   },
+
+   spritesheets = {
       working = {
-         pictures = path.list_files(dirname .. "working_??.png"),
-         hotspot = { 53, 68 },
-         fps = 20
-      }
+         fps = 20,
+         frames = 5,
+         columns = 5,
+         rows = 1,
+         hotspot = { 54, 74 },
+      },
    },
 
    aihints = {
@@ -51,8 +57,9 @@ descriptions:new_productionsite_type {
    programs = {
       main = {
          -- TRANSLATORS: Completed/Skipped/Did not start working because ...
-         descname = _"working",
+         descname = _("working"),
          actions = {
+            -- time total: 3 * 68 = 204 sec
             "call=smoke_fish",
             "call=smoke_meat",
             "call=smoke_fish_2",
@@ -60,12 +67,12 @@ descriptions:new_productionsite_type {
       },
       smoke_meat = {
          -- TRANSLATORS: Completed/Skipped/Did not start smoking meat because ...
-         descname = _"smoking meat",
+         descname = _("smoking meat"),
          actions = {
-            -- time total: 60
+            -- time: 30.8 + 30 + 2 * 3.6 = 68
             "return=skipped unless economy needs smoked_meat",
             "consume=meat:2 log",
-            "animate=working duration:30s",
+            "animate=working duration:30s800ms",
             "sleep=duration:30s",
             "produce=smoked_meat:2"
          }
@@ -73,24 +80,24 @@ descriptions:new_productionsite_type {
       -- 2 identical programs for fish to prevent unnecessary skipping penalty
       smoke_fish = {
          -- TRANSLATORS: Completed/Skipped/Did not start smoking fish because ...
-         descname = _"smoking fish",
+         descname = _("smoking fish"),
          actions = {
-            -- time total: 60
+            -- time: 30.8 + 30 + 2 * 3.6 = 68
             "return=skipped unless economy needs smoked_fish",
             "consume=fish:2 log",
-            "animate=working duration:30s",
+            "animate=working duration:30s800ms",
             "sleep=duration:30s",
             "produce=smoked_fish:2"
          }
       },
       smoke_fish_2 = {
          -- TRANSLATORS: Completed/Skipped/Did not start smoking fish because ...
-         descname = _"smoking fish",
+         descname = _("smoking fish"),
          actions = {
-            -- time total: 60
+            -- time: 30.8 + 30 + 2 * 3.6 = 68
             "return=skipped unless economy needs smoked_fish",
             "consume=fish:2 log",
-            "animate=working duration:30s",
+            "animate=working duration:30s800ms",
             "sleep=duration:30s",
             "produce=smoked_fish:2"
          }
