@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_productionsite_type {
+wl.Descriptions():new_productionsite_type {
    name = "barbarians_barracks",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Barracks"),
@@ -23,10 +23,10 @@ descriptions:new_productionsite_type {
 
    animation_directory = dirname,
    -- TODO(Nordfriese): Make animations.
-   animations = {idle = {hotspot = {57, 49}}},
+   animations = {idle = {hotspot = {55, 49}}},
    spritesheets = {
       build = {
-         hotspot = {57, 49},
+         hotspot = {55, 49},
          frames = 3,
          columns = 1,
          rows = 3
@@ -53,6 +53,7 @@ descriptions:new_productionsite_type {
          -- TRANSLATORS: Completed/Skipped/Did not start recruiting soldier because ...
          descname = pgettext("barbarians_building", "recruiting soldier"),
          actions = {
+            -- time total: 30 sec
             "return=skipped unless economy needs barbarians_soldier",
             "consume=ax barbarians_recruit",
             "sleep=duration:30s",
