@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_productionsite_type {
+wl.Descriptions():new_productionsite_type {
    name = "empire_mill",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("empire_building", "Mill"),
@@ -20,15 +20,32 @@ descriptions:new_productionsite_type {
       marble = 1
    },
 
-   animations = {
+   animation_directory = dirname,
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 41, 87 },
+         frames = 1,
+         columns = 1,
+         rows = 1,
+         hotspot = { 44, 90 },
+      },
+      build = {
+         frames = 2,
+         columns = 2,
+         rows = 1,
+         hotspot = { 44, 90 },
+      },
+      unoccupied = {
+         frames = 1,
+         columns = 1,
+         rows = 1,
+         hotspot = { 44, 90 },
       },
       working = {
-         pictures = path.list_files(dirname .. "working_??.png"),
-         hotspot = { 41, 87 },
-         fps = 25
+         fps = 15,
+         frames = 19,
+         columns = 10,
+         rows = 2,
+         hotspot = { 44, 90 },
       },
    },
 
@@ -47,7 +64,7 @@ descriptions:new_productionsite_type {
    programs = {
       main = {
          -- TRANSLATORS: Completed/Skipped/Did not start grinding wheat because ...
-         descname = _"grinding wheat",
+         descname = _("grinding wheat"),
          actions = {
             "return=skipped unless economy needs flour",
             "consume=wheat",
