@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_productionsite_type {
+wl.Descriptions():new_productionsite_type {
    name = "empire_tavern",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("empire_building", "Tavern"),
@@ -33,14 +33,20 @@ descriptions:new_productionsite_type {
       marble = 1
    },
 
-   animations = {
+   animation_directory = dirname,
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 52, 58 },
+         frames = 1,
+         columns = 1,
+         rows = 1,
+         hotspot = { 46, 55 },
       },
       working = {
-         pictures = path.list_files(dirname .. "idle_??.png"), -- TODO(GunChleoc): No animation yet.
-         hotspot = { 52, 58 },
+         basename = "idle", -- TODO(GunChleoc): No animation yet.
+         frames = 1,
+         columns = 1,
+         rows = 1,
+         hotspot = { 46, 55 },
       },
    },
 
@@ -62,12 +68,12 @@ descriptions:new_productionsite_type {
    programs = {
       main = {
          -- TRANSLATORS: Completed/Skipped/Did not start preparing a ration because ...
-         descname = _"preparing a ration",
+         descname = _("preparing a ration"),
          actions = {
-            -- time total: 33
+            -- time total: 5.4 + 18 + 10 + 3.6 = 37 sec
             "return=skipped unless economy needs ration",
             "consume=empire_bread,fish,meat",
-            "sleep=duration:5s",
+            "sleep=duration:5s400ms",
             "playsound=sound/empire/taverns/ration priority:80%",
             "animate=working duration:18s",
             "sleep=duration:10s",
