@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_productionsite_type {
+wl.Descriptions():new_productionsite_type {
    name = "empire_toolsmithy",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("empire_building", "Toolsmithy"),
@@ -20,14 +20,20 @@ descriptions:new_productionsite_type {
       marble = 2
    },
 
-   animations = {
+   animation_directory = dirname,
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 58, 61 },
+         frames = 1,
+         columns = 1,
+         rows = 1,
+         hotspot = { 63, 64 },
       },
       working = {
-         pictures = path.list_files(dirname .. "idle_??.png"), -- TODO(GunChleoc): No animation yet.
-         hotspot = { 58, 61 },
+         basename = "idle", -- TODO(GunChleoc): No animation yet.
+         frames = 1,
+         columns = 1,
+         rows = 1,
+         hotspot = { 63, 64 },
       },
    },
 
@@ -47,8 +53,9 @@ descriptions:new_productionsite_type {
    programs = {
       main = {
          -- TRANSLATORS: Completed/Skipped/Did not start working because ...
-         descname = _"working",
+         descname = _("working"),
          actions = {
+            -- time total: 12 * 71 = 852 sec
             "call=produce_felling_ax",
             "call=produce_basket",
             "call=produce_bread_paddle",
@@ -65,11 +72,12 @@ descriptions:new_productionsite_type {
       },
       produce_felling_ax = {
          -- TRANSLATORS: Completed/Skipped/Did not start making a felling ax because ...
-         descname = _"making a felling ax",
+         descname = _("making a felling ax"),
          actions = {
+            -- time: 32.4 + 35 + 3.6 = 71 sec
             "return=skipped unless economy needs felling_ax",
             "consume=iron log",
-            "sleep=duration:32s",
+            "sleep=duration:32s400ms",
             "playsound=sound/smiths/toolsmith priority:50% allow_multiple",
             "animate=working duration:35s",
             "produce=felling_ax"
@@ -77,11 +85,12 @@ descriptions:new_productionsite_type {
       },
       produce_basket = {
          -- TRANSLATORS: Completed/Skipped/Did not start making a basket because ...
-         descname = _"making a basket",
+         descname = _("making a basket"),
          actions = {
+            -- time: 32.4 + 35 + 3.6 = 71 sec
             "return=skipped unless economy needs basket",
             "consume=iron log",
-            "sleep=duration:32s",
+            "sleep=duration:32s400ms",
             "playsound=sound/smiths/toolsmith priority:50% allow_multiple",
             "animate=working duration:35s",
             "produce=basket"
@@ -89,11 +98,12 @@ descriptions:new_productionsite_type {
       },
       produce_bread_paddle = {
          -- TRANSLATORS: Completed/Skipped/Did not start making a bread paddle because ...
-         descname = _"making a bread paddle",
+         descname = _("making a bread paddle"),
          actions = {
+            -- time: 32.4 + 35 + 3.6 = 71 sec
             "return=skipped unless economy needs bread_paddle",
             "consume=iron log",
-            "sleep=duration:32s",
+            "sleep=duration:32s400ms",
             "playsound=sound/smiths/toolsmith priority:50% allow_multiple",
             "animate=working duration:35s",
             "produce=bread_paddle"
@@ -101,11 +111,12 @@ descriptions:new_productionsite_type {
       },
       produce_fire_tongs = {
          -- TRANSLATORS: Completed/Skipped/Did not start making fire tongs because ...
-         descname = _"making fire tongs",
+         descname = _("making fire tongs"),
          actions = {
+            -- time: 32.4 + 35 + 3.6 = 71 sec
             "return=skipped unless economy needs fire_tongs",
             "consume=iron log",
-            "sleep=duration:32s",
+            "sleep=duration:32s400ms",
             "playsound=sound/smiths/toolsmith priority:50% allow_multiple",
             "animate=working duration:35s",
             "produce=fire_tongs"
@@ -113,11 +124,12 @@ descriptions:new_productionsite_type {
       },
       produce_fishing_rod = {
          -- TRANSLATORS: Completed/Skipped/Did not start making a fishing rod because ...
-         descname = _"making a fishing rod",
+         descname = _("making a fishing rod"),
          actions = {
+            -- time: 32.4 + 35 + 3.6 = 71 sec
             "return=skipped unless economy needs fishing_rod",
             "consume=iron log",
-            "sleep=duration:32s",
+            "sleep=duration:32s400ms",
             "playsound=sound/smiths/toolsmith priority:50% allow_multiple",
             "animate=working duration:35s",
             "produce=fishing_rod"
@@ -125,11 +137,12 @@ descriptions:new_productionsite_type {
       },
       produce_hammer = {
          -- TRANSLATORS: Completed/Skipped/Did not start making a hammer because ...
-         descname = _"making a hammer",
+         descname = _("making a hammer"),
          actions = {
+            -- time: 32.4 + 35 + 3.6 = 71 sec
             "return=skipped unless economy needs hammer",
             "consume=iron log",
-            "sleep=duration:32s",
+            "sleep=duration:32s400ms",
             "playsound=sound/smiths/toolsmith priority:50% allow_multiple",
             "animate=working duration:35s",
             "produce=hammer"
@@ -137,11 +150,12 @@ descriptions:new_productionsite_type {
       },
       produce_hunting_spear = {
          -- TRANSLATORS: Completed/Skipped/Did not start making a hunting spear because ...
-         descname = _"making a hunting spear",
+         descname = _("making a hunting spear"),
          actions = {
+            -- time: 32.4 + 35 + 3.6 = 71 sec
             "return=skipped unless economy needs hunting_spear",
             "consume=iron log",
-            "sleep=duration:32s",
+            "sleep=duration:32s400ms",
             "playsound=sound/smiths/toolsmith priority:50% allow_multiple",
             "animate=working duration:35s",
             "produce=hunting_spear"
@@ -149,11 +163,12 @@ descriptions:new_productionsite_type {
       },
       produce_kitchen_tools = {
          -- TRANSLATORS: Completed/Skipped/Did not start making kitchen tools because ...
-         descname = _"making kitchen tools",
+         descname = _("making kitchen tools"),
          actions = {
+            -- time: 32.4 + 35 + 3.6 = 71 sec
             "return=skipped unless economy needs kitchen_tools",
             "consume=iron log",
-            "sleep=duration:32s",
+            "sleep=duration:32s400ms",
             "playsound=sound/smiths/toolsmith priority:50% allow_multiple",
             "animate=working duration:35s",
             "produce=kitchen_tools"
@@ -161,11 +176,12 @@ descriptions:new_productionsite_type {
       },
       produce_pick = {
          -- TRANSLATORS: Completed/Skipped/Did not start making a pick because ...
-         descname = _"making a pick",
+         descname = _("making a pick"),
          actions = {
+            -- time: 32.4 + 35 + 3.6 = 71 sec
             "return=skipped unless economy needs pick",
             "consume=iron log",
-            "sleep=duration:32s",
+            "sleep=duration:32s400ms",
             "playsound=sound/smiths/toolsmith priority:50% allow_multiple",
             "animate=working duration:35s",
             "produce=pick"
@@ -173,11 +189,12 @@ descriptions:new_productionsite_type {
       },
       produce_saw = {
          -- TRANSLATORS: Completed/Skipped/Did not start making a saw because ...
-         descname = _"making a saw",
+         descname = _("making a saw"),
          actions = {
+            -- time: 32.4 + 35 + 3.6 = 71 sec
             "return=skipped unless economy needs saw",
             "consume=iron log",
-            "sleep=duration:32s",
+            "sleep=duration:32s400ms",
             "playsound=sound/smiths/toolsmith priority:50% allow_multiple",
             "animate=working duration:35s",
             "produce=saw"
@@ -185,11 +202,12 @@ descriptions:new_productionsite_type {
       },
       produce_scythe = {
          -- TRANSLATORS: Completed/Skipped/Did not start making a scythe because ...
-         descname = _"making a scythe",
+         descname = _("making a scythe"),
          actions = {
+            -- time: 32.4 + 35 + 3.6 = 71 sec
             "return=skipped unless economy needs scythe",
             "consume=iron log",
-            "sleep=duration:32s",
+            "sleep=duration:32s400ms",
             "playsound=sound/smiths/toolsmith priority:50% allow_multiple",
             "animate=working duration:35s",
             "produce=scythe"
@@ -197,11 +215,12 @@ descriptions:new_productionsite_type {
       },
       produce_shovel = {
          -- TRANSLATORS: Completed/Skipped/Did not start making a shovel because ...
-         descname = _"making a shovel",
+         descname = _("making a shovel"),
          actions = {
+            -- time: 32.4 + 35 + 3.6 = 71 sec
             "return=skipped unless economy needs shovel",
             "consume=iron log",
-            "sleep=duration:32s",
+            "sleep=duration:32s400ms",
             "playsound=sound/smiths/toolsmith priority:50% allow_multiple",
             "animate=working duration:35s",
             "produce=shovel"
