@@ -1,11 +1,12 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_productionsite_type {
+wl.Descriptions():new_productionsite_type {
    name = "frisians_ferry_yard",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("frisians_building", "Ferry Yard"),
+   animation_directory = dirname,
    icon = dirname .. "menu.png",
    size = "medium",
    map_check = {"waterways"},
@@ -25,8 +26,6 @@ descriptions:new_productionsite_type {
 
    spritesheets = {
       idle = {
-         directory = dirname,
-         basename = "idle",
          hotspot = {50, 75},
          frames = 10,
          columns = 5,
@@ -36,8 +35,6 @@ descriptions:new_productionsite_type {
    },
    animations = {
       unoccupied = {
-         directory = dirname,
-         basename = "unoccupied",
          hotspot = {50, 58}
       }
    },
@@ -56,12 +53,12 @@ descriptions:new_productionsite_type {
    programs = {
       main = {
          -- TRANSLATORS: Completed/Skipped/Did not start working because ...
-         descname = _"working",
+         descname = _("working"),
          actions = {
             "sleep=duration:20s",
-            "callworker=buildferry_1",
+            "return=skipped unless fleet needs ferry",
             "consume=log:2 cloth",
-            "callworker=buildferry_2"
+            "callworker=buildferry"
          }
       },
    },
