@@ -1,11 +1,12 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_productionsite_type {
+wl.Descriptions():new_productionsite_type {
    name = "frisians_foresters_house",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("frisians_building", "Forester’s House"),
+   animation_directory = dirname,
    icon = dirname .. "menu.png",
    size = "small",
 
@@ -21,8 +22,6 @@ descriptions:new_productionsite_type {
 
    spritesheets = {
       idle = {
-         directory = dirname,
-         basename = "idle",
          hotspot = {40, 73},
          frames = 10,
          columns = 5,
@@ -32,8 +31,6 @@ descriptions:new_productionsite_type {
    },
    animations = {
       unoccupied = {
-         directory = dirname,
-         basename = "unoccupied",
          hotspot = {40, 56}
       }
    },
@@ -49,8 +46,12 @@ descriptions:new_productionsite_type {
    programs = {
       main = {
          -- TRANSLATORS: Completed/Skipped/Did not start planting trees because ...
-         descname = _"planting trees",
+         descname = _("planting trees"),
          actions = {
+            -- time of worker: 12.2-33.8 sec, mean 22.784 sec
+            -- min. time total: 12.2 + 12 = 24.2 sec
+            -- max. time total: 33.8 + 12 = 45.8 sec
+            -- mean time total: 22.784 + 12 = 34.784 sec
             "callworker=plant",
             "sleep=duration:12s"
          }
