@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_warehouse_type {
+wl.Descriptions():new_warehouse_type {
    name = "barbarians_headquarters",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("barbarians_building", "Headquarters"),
@@ -10,14 +10,17 @@ descriptions:new_warehouse_type {
    size = "big",
    destructible = false,
 
-   -- The Headquarters of the barbarians is from the apperance a stable military
+   -- The Headquarters of the Barbarians is from the apperance a stable military
    -- Building, fortified base and some towers made of blackwood. Some flags
    -- in the player colors may be present
-   animations = {
+   animation_directory = dirname,
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 90, 96 },
-         fps = 10
+         fps = 10,
+         frames = 20,
+         rows = 5,
+         columns = 4,
+         hotspot = { 90, 96 }
       },
    },
 
@@ -25,6 +28,7 @@ descriptions:new_warehouse_type {
 
    heal_per_second = 220,
    conquers = 9,
+   max_garrison = 20,
 }
 
 pop_textdomain()
