@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_warehouse_type {
+wl.Descriptions():new_warehouse_type {
    name = "empire_headquarters_shipwreck",
    -- TRANSLATORS: This is a building name used in lists of buildings
    descname = pgettext("empire_building", "Headquarters Shipwreck"),
@@ -10,10 +10,13 @@ descriptions:new_warehouse_type {
    size = "big",
    destructible = false,
 
-   animations = {
+   animation_directory = dirname,
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 93, 40 },
+         frames = 1,
+         columns = 1,
+         rows = 1,
+         hotspot = { 102, 57 },
       },
    },
 
@@ -21,6 +24,7 @@ descriptions:new_warehouse_type {
 
    heal_per_second = 170,
    conquers = 9,
+   max_garrison = 20,
 }
 
 pop_textdomain()
