@@ -26,7 +26,19 @@
 --    **programs**: A table with the programs that this immovable will perform,
 --    e.g. ``{ "animate=idle duration:2m30s500ms",  "remove=" }`` (see :ref:`immovable_programs`)
 --
---    **animations**: A table containing all animations for this immovable.
+--    **animations**
+--        *Optional*. A table containing all file animations for this immovable.
+--        Every immovable needs to have at least an ``idle`` animation.
+--        Animations can either be defined as file animations in this table or as spritesheet animations
+--        as defined in table ``spritesheets``. A mixture of the two animation formats is allowed.
+--        See :doc:`animations` for a detailed description of the animation format.
+--
+--    **spritesheets**
+--        *Optional*. A table containing all spritesheet animations for this immovable.
+--        Every immovable needs to have at least an ``idle`` animation.
+--        Animations can either be defined as spritesheet animations in this table or as file animations
+--        as defined in table ``animations``. A mixture of the two animation formats is allowed.
+--        See :doc:`animations` for a detailed description of the animation format.
 --
 -- For making the UI texts translateable, we also need to push/pop the correct textdomain.
 --
@@ -38,7 +50,7 @@
 --
 --    dirname = path.dirname(__file__)
 --
---    descriptions:new_immovable_type {
+--    wl.Descriptions():new_immovable_type {
 --       name = "ashes",
 --       descname = pgettext("immovable", "Ashes"),
 --       anmation_directory = dirname,
@@ -62,12 +74,13 @@
 
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_immovable_type {
+wl.Descriptions():new_immovable_type {
    name = "ashes",
    -- TRANSLATORS: This is an immovable name used in lists of immovables
    descname = pgettext("immovable", "Ashes"),
+   animation_directory = dirname,
    icon = dirname .. "menu.png",
    size = "small",
    programs = {
@@ -77,10 +90,12 @@ descriptions:new_immovable_type {
       }
    },
 
-   animations = {
+   spritesheets = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 40, 39 },
+         frames = 1,
+         columns = 1,
+         rows = 1,
+         hotspot = { 43, 60 },
       },
    }
 }
