@@ -1,11 +1,12 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_immovable_type {
+wl.Descriptions():new_immovable_type {
    name = "barleyfield_harvested",
    -- TRANSLATORS: This is an immovable name used in lists of immovables
    descname = pgettext("immovable", "Barley Field (harvested)"),
+   animation_directory = dirname,
    icon = dirname .. "menu.png",
    programs = {
       main = {
@@ -15,8 +16,6 @@ descriptions:new_immovable_type {
    },
    animations = {
       idle = {
-         directory = dirname,
-         basename = "idle",
          hotspot = {21, 34}
       }
    }
