@@ -1,13 +1,13 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_immovable_type {
+wl.Descriptions():new_immovable_type {
    name = "grapevine_tiny",
    -- TRANSLATORS: This is an immovable name used in lists of immovables
    descname = pgettext("immovable", "Grapevine (tiny)"),
    icon = dirname .. "menu.png",
-   size = "medium",
+   size = "small",
    programs = {
       main = {
          "animate=idle duration:22s",
@@ -15,10 +15,10 @@ descriptions:new_immovable_type {
       }
    },
 
+   animation_directory = dirname,
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle_??.png"),
-         hotspot = { 15, 18 },
+         hotspot = { 17, 27 },
       },
    }
 }
