@@ -1,12 +1,12 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
 
-descriptions:new_immovable_type{
+wl.Descriptions():new_immovable_type{
    name = "deadtree7",
-   -- TRANSLATORS:  This is an amazon rare tree.
-   descname = _ "Dead Tree",
+   -- TRANSLATORS:  This is an Amazon rare tree.
+   descname = _("Dead Tree"),
    size = "small",
    terrain_affinity = terrain_affinity,
    programs = {
