@@ -1,17 +1,17 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_ware_type {
+wl.Descriptions():new_ware_type {
    name = "cloth",
    -- TRANSLATORS: This is a ware name used in lists of wares
    descname = pgettext("ware", "Cloth"),
    icon = dirname .. "menu.png",
 
+   animation_directory = dirname,
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle.png"),
-         hotspot = { 6, 9 },
+         hotspot = { 9, 12 },
       },
    }
 }
