@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_ware_type {
+wl.Descriptions():new_ware_type {
    name = "rubber",
    -- TRANSLATORS: This is a ware name used in lists of wares
    descname = pgettext("ware", "Rubber"),
