@@ -1,16 +1,16 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_ware_type {
+wl.Descriptions():new_ware_type {
    name = "trident_double",
    -- TRANSLATORS: This is a ware name used in lists of wares
    descname = pgettext("ware", "Double Trident"),
    icon = dirname .. "menu.png",
 
+   animation_directory = dirname,
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle.png"),
          hotspot = { 10, 17 },
       },
    }
