@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_worker_type {
+wl.Descriptions():new_worker_type {
    name = "atlanteans_miller",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext("atlanteans_worker", "Miller"),
@@ -18,17 +18,26 @@ descriptions:new_worker_type {
       idle = {
          hotspot = { 4, 22 }
       },
+   },
+
+   spritesheets = {
       walk = {
-         hotspot = { 8, 22 },
          fps = 10,
-         directional = true
+         frames = 10,
+         rows = 4,
+         columns = 3,
+         directional = true,
+         hotspot = { 8, 22 }
       },
       walkload = {
-         hotspot = { 8, 24 },
          fps = 10,
-         directional = true
-      }
-   }
+         frames = 10,
+         rows = 4,
+         columns = 3,
+         directional = true,
+         hotspot = { 8, 24 }
+      },
+   },
 }
 
 pop_textdomain()
