@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_worker_type {
+wl.Descriptions():new_worker_type {
    name = "barbarians_lumberjack",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext("barbarians_worker", "Lumberjack"),
@@ -17,6 +17,11 @@ descriptions:new_worker_type {
 
    programs = {
       harvest = {
+         -- steps from building to tree: 2-13, min+max average 7.5
+         -- min. worker time: 2 * 2 * 1.8 + 15 + 2 = 24.2 sec
+         -- max. worker time: 2 * 13 * 1.8 + 15 + 2 = 63.8 sec
+         -- avg. worker time: 2 * 7.5 * 1.8 + 15 + 2 = 44 sec
+         -- some of trees delay woodcutting by 1-1.4 sec (aspen, balsa, ironwood, oak, rubber)
          "findobject=attrib:tree radius:10",
          "walk=object",
          "playsound=sound/woodcutting/woodcutting priority:100% allow_multiple",
