@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_worker_type {
+wl.Descriptions():new_worker_type {
    name = "empire_shepherd",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext("empire_worker", "Shepherd"),
@@ -18,18 +18,27 @@ descriptions:new_worker_type {
       idle = {
          hotspot = { 16, 29 }
       },
+   },
+
+   spritesheets = {
       walk = {
-         hotspot = { 26, 30 },
          fps = 20,
-         directional = true
+         frames = 20,
+         rows = 5,
+         columns = 4,
+         directional = true,
+         hotspot = { 26, 30 }
       },
       walkload = {
          basename = "walk",
-         hotspot = { 26, 30 },
          fps = 20,
-         directional = true
-      }
-   }
+         frames = 20,
+         rows = 5,
+         columns = 4,
+         directional = true,
+         hotspot = { 26, 30 }
+      },
+   },
 }
 
 pop_textdomain()
