@@ -1,8 +1,8 @@
 push_textdomain("tribes")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
-descriptions:new_worker_type {
+wl.Descriptions():new_worker_type {
    name = "empire_weaver",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext("empire_worker", "Weaver"),
@@ -18,16 +18,25 @@ descriptions:new_worker_type {
       idle = {
          hotspot = { 4, 24 }
       },
+   },
+
+   spritesheets = {
       walk = {
-         hotspot = { 6, 26 },
          fps = 10,
-         directional = true
+         frames = 10,
+         rows = 4,
+         columns = 3,
+         directional = true,
+         hotspot = { 6, 26 }
       },
       walkload = {
-         hotspot = { 6, 26 },
          fps = 10,
-         directional = true
-      }
+         frames = 10,
+         rows = 4,
+         columns = 3,
+         directional = true,
+         hotspot = { 6, 26 }
+      },
    }
 }
 
