@@ -1,11 +1,12 @@
 push_textdomain("tribes")
 
-dirname = path.dirname (__file__)
+local dirname = path.dirname (__file__)
 
-descriptions:new_worker_type {
+wl.Descriptions():new_worker_type {
    name = "frisians_beekeeper",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext ("frisians_worker", "Beekeeper"),
+   animation_directory = dirname,
    icon = dirname .. "menu.png",
    vision_range = 2,
 
@@ -27,8 +28,6 @@ descriptions:new_worker_type {
 
    spritesheets = {
       walk = {
-         directory = dirname,
-         basename = "walk",
          fps = 15,
          frames = 10,
          columns = 5,
@@ -37,8 +36,6 @@ descriptions:new_worker_type {
          hotspot = {11, 24}
       },
       walkload = {
-         directory = dirname,
-         basename = "walkload",
          fps = 15,
          frames = 10,
          columns = 5,
@@ -47,8 +44,6 @@ descriptions:new_worker_type {
          hotspot = {10, 26}
       },
       beeswarm = {
-         directory = dirname,
-         basename = "beeswarm",
          fps = 50,
          frames = 100,
          columns = 5,
@@ -58,8 +53,6 @@ descriptions:new_worker_type {
    },
    animations = {
       idle = {
-         directory = dirname,
-         basename = "idle",
          hotspot = {8, 23}
       },
    },
