@@ -1,11 +1,12 @@
 push_textdomain("tribes")
 
-dirname = path.dirname (__file__)
+local dirname = path.dirname (__file__)
 
 wl.Descriptions():new_worker_type {
    name = "frisians_fruit_collector",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext ("frisians_worker", "Fruit Collector"),
+   animation_directory = dirname,
    icon = dirname .. "menu.png",
    vision_range = 2,
 
@@ -30,8 +31,6 @@ wl.Descriptions():new_worker_type {
 
    spritesheets = {
       walk = {
-         directory = dirname,
-         basename = "walk",
          fps = 15,
          frames = 10,
          columns = 5,
@@ -40,8 +39,6 @@ wl.Descriptions():new_worker_type {
          hotspot = {11, 23}
       },
       walkload = {
-         directory = dirname,
-         basename = "walkload",
          fps = 15,
          frames = 10,
          columns = 5,
@@ -50,8 +47,6 @@ wl.Descriptions():new_worker_type {
          hotspot = {10, 26}
       },
       idle = {
-         directory = dirname,
-         basename = "idle",
          fps = 10,
          frames = 10,
          columns = 5,
@@ -59,7 +54,6 @@ wl.Descriptions():new_worker_type {
          hotspot = {8, 23}
       },
       gather = {
-         directory = dirname,
          basename = "harvest",
          fps = 10,
          frames = 10,
