@@ -1,11 +1,12 @@
 push_textdomain("tribes")
 
-dirname = path.dirname (__file__)
+local dirname = path.dirname (__file__)
 
 wl.Descriptions():new_worker_type {
    name = "frisians_reindeer_breeder",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext ("frisians_worker", "Reindeer Breeder"),
+   animation_directory = dirname,
    icon = dirname .. "menu.png",
    vision_range = 2,
 
@@ -17,8 +18,6 @@ wl.Descriptions():new_worker_type {
 
    spritesheets = {
       walk = {
-         directory = dirname,
-         basename = "walk",
          fps = 15,
          frames = 10,
          columns = 5,
@@ -27,8 +26,6 @@ wl.Descriptions():new_worker_type {
          hotspot = {10, 23}
       },
       walkload = {
-         directory = dirname,
-         basename = "walkload",
          fps = 15,
          frames = 10,
          columns = 5,
@@ -39,8 +36,6 @@ wl.Descriptions():new_worker_type {
    },
    animations = {
       idle = {
-         directory = dirname,
-         basename = "idle",
          hotspot = {8, 23}
       },
    },
