@@ -1,6 +1,6 @@
 push_textdomain("tribes")
 
-dirname = path.dirname (__file__)
+local dirname = path.dirname (__file__)
 
 -- Quick overview: We use 4 sets of animations here.
 -- The default set (fri_rookie, "rookie") is for soldiers with no helmet and one sword.
@@ -20,428 +20,563 @@ dirname = path.dirname (__file__)
 -- Oh, and by the way, the soldiers' swords are not long enough to touch the opponent if the
 -- hotspot is at the soldier's feet. That's why all battle hotspots are shifted by 3 pixels.
 --
--- The above explanation refers only to frisian soldiers. Other tribes's soldiers
+-- The above explanation refers only to Frisian soldiers. Other tribes's soldiers
 -- may follow other conventions described in their respective init.lua's.
 
-animations = {
+spritesheets = {
    -- Rookie
    idle = {
       directory = dirname .. "rookie",
-      basename = "idle",
-      hotspot = {20, 24},
-      fps = 10
+      fps = 10,
+      frames = 50,
+      rows = 8,
+      columns = 7,
+      hotspot = { 7, 23 }
    },
    walk = {
       directory = dirname .. "rookie",
-      basename = "walk",
-      hotspot = {7, 24},
       fps = 15,
-      directional = true
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      directional = true,
+      hotspot = { 7, 24 }
    },
    atk_ok_1_e = {
       directory = dirname .. "rookie",
-      basename = "atk_ok_1_e",
-      hotspot = {23, 24},
-      fps = 10
-   },
-   atk_fail_1_e = {
-      directory = dirname .. "rookie",
-      basename = "atk_fail_1_e",
-      hotspot = {23, 23},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 24 }
    },
    atk_ok_1_w = {
       directory = dirname .. "rookie",
-      basename = "atk_ok_1_w",
-      hotspot = {-1, 22},
-      fps = 10
-   },
-   atk_fail_1_w = {
-      directory = dirname .. "rookie",
-      basename = "atk_fail_1_w",
-      hotspot = {-1, 22},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 22 }
    },
    atk_ok_2_e = {
       directory = dirname .. "rookie",
-      basename = "atk_ok_2_e",
-      hotspot = {23, 23},
-      fps = 10
-   },
-   atk_fail_2_e = {
-      directory = dirname .. "rookie",
-      basename = "atk_fail_2_e",
-      hotspot = {23, 23},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 23 }
    },
    atk_ok_2_w = {
       directory = dirname .. "rookie",
-      basename = "atk_ok_2_w",
-      hotspot = {-1, 23},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 23 }
+   },
+   atk_fail_1_e = {
+      directory = dirname .. "rookie",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 23 }
+   },
+   atk_fail_1_w = {
+      directory = dirname .. "rookie",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 22 }
+   },
+   atk_fail_2_e = {
+      directory = dirname .. "rookie",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 23 }
    },
    atk_fail_2_w = {
       directory = dirname .. "rookie",
-      basename = "atk_fail_2_w",
-      hotspot = {-1, 23},
-      fps = 10
-   },
-   eva_ok_e = {
-      directory = dirname .. "rookie",
-      basename = "eva_ok_e",
-      hotspot = {11, 23},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 23 }
    },
    eva_fail_e = {
       directory = dirname .. "rookie",
-      basename = "eva_fail_e",
-      hotspot = {12, 23},
-      fps = 10
-   },
-   eva_ok_w = {
-      directory = dirname .. "rookie",
-      basename = "eva_ok_w",
-      hotspot = {-1, 22},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 12, 23 }
    },
    eva_fail_w = {
       directory = dirname .. "rookie",
-      basename = "eva_fail_w",
-      hotspot = {-1, 22},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 22 }
    },
-   die_w = {
+   eva_ok_e = {
       directory = dirname .. "rookie",
-      basename = "die_w",
-      hotspot = {15, 25},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 11, 23 }
+   },
+   eva_ok_w = {
+      directory = dirname .. "rookie",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 22 }
    },
    die_e = {
       directory = dirname .. "rookie",
-      basename = "die_e",
-      hotspot = {12, 23},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 12, 23 }
+   },
+   die_w = {
+      directory = dirname .. "rookie",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 15, 25 }
    },
-
    -- Health upgrade only
    health_idle = {
       directory = dirname .. "helm",
-      basename = "idle",
-      hotspot = {20, 25},
-      fps = 10
+      fps = 10,
+      frames = 50,
+      rows = 8,
+      columns = 7,
+      hotspot = { 7, 25 }
    },
    health_walk = {
       directory = dirname .. "helm",
-      basename = "walk",
-      hotspot = {7, 25},
       fps = 15,
-      directional = true
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      directional = true,
+      hotspot = { 7, 25 }
    },
    health_atk_ok_1_e = {
       directory = dirname .. "helm",
-      basename = "atk_ok_1_e",
-      hotspot = {23, 24},
-      fps = 10
-   },
-   health_atk_fail_1_e = {
-      directory = dirname .. "helm",
-      basename = "atk_fail_1_e",
-      hotspot = {23, 24},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 24 }
    },
    health_atk_ok_1_w = {
       directory = dirname .. "helm",
-      basename = "atk_ok_1_w",
-      hotspot = {-1, 24},
-      fps = 10
-   },
-   health_atk_fail_1_w = {
-      directory = dirname .. "helm",
-      basename = "atk_fail_1_w",
-      hotspot = {-1, 24},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 24 }
    },
    health_atk_ok_2_e = {
       directory = dirname .. "helm",
-      basename = "atk_ok_2_e",
-      hotspot = {23, 24},
-      fps = 10
-   },
-   health_atk_fail_2_e = {
-      directory = dirname .. "helm",
-      basename = "atk_fail_2_e",
-      hotspot = {23, 24},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 24 }
    },
    health_atk_ok_2_w = {
       directory = dirname .. "helm",
-      basename = "atk_ok_2_w",
-      hotspot = {-1, 24},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 24 }
+   },
+   health_atk_fail_1_e = {
+      directory = dirname .. "helm",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 24 }
+   },
+   health_atk_fail_1_w = {
+      directory = dirname .. "helm",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 24 }
+   },
+   health_atk_fail_2_e = {
+      directory = dirname .. "helm",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 24 }
    },
    health_atk_fail_2_w = {
       directory = dirname .. "helm",
-      basename = "atk_fail_2_w",
-      hotspot = {-1, 24},
-      fps = 10
-   },
-   health_eva_ok_e = {
-      directory = dirname .. "helm",
-      basename = "eva_ok_e",
-      hotspot = {11, 24},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 24 }
    },
    health_eva_fail_e = {
       directory = dirname .. "helm",
-      basename = "eva_fail_e",
-      hotspot = {12, 24},
-      fps = 10
-   },
-   health_eva_ok_w = {
-      directory = dirname .. "helm",
-      basename = "eva_ok_w",
-      hotspot = {-1, 24},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 12, 24 }
    },
    health_eva_fail_w = {
       directory = dirname .. "helm",
-      basename = "eva_fail_w",
-      hotspot = {-1, 24},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 24 }
    },
-   health_die_f_w = {
+   health_eva_ok_e = {
       directory = dirname .. "helm",
-      basename = "die_f_w",
-      hotspot = {-1, 24},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 11, 24 }
+   },
+   health_eva_ok_w = {
+      directory = dirname .. "helm",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 24 }
    },
    health_die_f_e = {
       directory = dirname .. "helm",
-      basename = "die_f_e",
-      hotspot = {19, 24},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 19, 24 }
    },
-   health_die_b_w = {
+   health_die_f_w = {
       directory = dirname .. "helm",
-      basename = "die_b_w",
-      hotspot = {15, 24},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 24 }
    },
    health_die_b_e = {
       directory = dirname .. "helm",
-      basename = "die_b_e",
-      hotspot = {12, 24},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 12, 24 }
+   },
+   health_die_b_w = {
+      directory = dirname .. "helm",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 15, 24 }
    },
 
    -- Health and attack upgrade
    hero_idle = {
       directory = dirname .. "hero",
-      basename = "idle",
-      hotspot = {20, 25},
-      fps = 10
+      fps = 10,
+      frames = 50,
+      rows = 8,
+      columns = 7,
+      hotspot = { 8, 25 }
    },
    hero_walk = {
       directory = dirname .. "hero",
-      basename = "walk",
-      hotspot = {8, 25},
       fps = 15,
-      directional = true
-   },
-   hero_atk_ok_1_e = {
-      directory = dirname .. "hero",
-      basename = "atk_ok_1_e",
-      hotspot = {23, 25},
-      fps = 10
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      directional = true,
+      hotspot = { 8, 25 }
    },
    hero_atk_fail_1_e = {
       directory = dirname .. "hero",
-      basename = "atk_fail_1_e",
-      hotspot = {22, 25},
-      fps = 10
-   },
-   hero_atk_ok_1_w = {
-      directory = dirname .. "hero",
-      basename = "atk_ok_1_w",
-      hotspot = {0, 25},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 22, 25 }
    },
    hero_atk_fail_1_w = {
       directory = dirname .. "hero",
-      basename = "atk_fail_1_w",
-      hotspot = {0, 25},
-      fps = 10
-   },
-   hero_atk_ok_2_e = {
-      directory = dirname .. "hero",
-      basename = "atk_ok_2_e",
-      hotspot = {23, 25},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 0, 25 }
    },
    hero_atk_fail_2_e = {
       directory = dirname .. "hero",
-      basename = "atk_fail_2_e",
-      hotspot = {23, 25},
-      fps = 10
-   },
-   hero_atk_ok_2_w = {
-      directory = dirname .. "hero",
-      basename = "atk_ok_2_w",
-      hotspot = {0, 25},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 25 }
    },
    hero_atk_fail_2_w = {
       directory = dirname .. "hero",
-      basename = "atk_fail_2_w",
-      hotspot = {0, 25},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 0, 25 }
    },
-   hero_eva_ok_e = {
+   hero_atk_ok_1_e = {
       directory = dirname .. "hero",
-      basename = "eva_ok_e",
-      hotspot = {13, 25},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 25 }
+   },
+   hero_atk_ok_1_w = {
+      directory = dirname .. "hero",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 0, 25 }
+   },
+   hero_atk_ok_2_e = {
+      directory = dirname .. "hero",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 25 }
+   },
+   hero_atk_ok_2_w = {
+      directory = dirname .. "hero",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 0, 25 }
    },
    hero_eva_fail_e = {
       directory = dirname .. "hero",
-      basename = "eva_fail_e",
-      hotspot = {13, 25},
-      fps = 10
-   },
-   hero_eva_ok_w = {
-      directory = dirname .. "hero",
-      basename = "eva_ok_w",
-      hotspot = {0, 25},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 13, 25 }
    },
    hero_eva_fail_w = {
       directory = dirname .. "hero",
-      basename = "eva_fail_w",
-      hotspot = {0, 25},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 0, 25 }
    },
-   hero_die_w = {
+   hero_eva_ok_e = {
       directory = dirname .. "hero",
-      basename = "die_w",
-      hotspot = {-1, 24},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 13, 25 }
+   },
+   hero_eva_ok_w = {
+      directory = dirname .. "hero",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 0, 25 }
    },
    hero_die_e = {
       directory = dirname .. "hero",
-      basename = "die_e",
-      hotspot = {19, 24},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 19, 24 }
+   },
+   hero_die_w = {
+      directory = dirname .. "hero",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 24 }
    },
 
    -- Sword upgrade only
    attack_idle = {
       directory = dirname .. "sword",
-      basename = "idle",
-      hotspot = {20, 25},
-      fps = 10
+      fps = 10,
+      frames = 50,
+      rows = 8,
+      columns = 7,
+      hotspot = { 8, 23 }
    },
    attack_walk = {
       directory = dirname .. "sword",
-      basename = "walk",
-      hotspot = {8, 24},
       fps = 15,
-      directional = true
-   },
-   attack_atk_ok_1_e = {
-      directory = dirname .. "sword",
-      basename = "atk_ok_1_e",
-      hotspot = {23, 24},
-      fps = 10
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      directional = true,
+      hotspot = { 8, 24 }
    },
    attack_atk_fail_1_e = {
       directory = dirname .. "sword",
-      basename = "atk_fail_1_e",
-      hotspot = {23, 24},
-      fps = 10
-   },
-   attack_atk_ok_1_w = {
-      directory = dirname .. "sword",
-      basename = "atk_ok_1_w",
-      hotspot = {0, 23},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 24 }
    },
    attack_atk_fail_1_w = {
       directory = dirname .. "sword",
-      basename = "atk_fail_1_w",
-      hotspot = {0, 23},
-      fps = 10
-   },
-   attack_atk_ok_2_e = {
-      directory = dirname .. "sword",
-      basename = "atk_ok_2_e",
-      hotspot = {23, 23},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 0, 23 }
    },
    attack_atk_fail_2_e = {
       directory = dirname .. "sword",
-      basename = "atk_fail_2_e",
-      hotspot = {23, 23},
-      fps = 10
-   },
-   attack_atk_ok_2_w = {
-      directory = dirname .. "sword",
-      basename = "atk_ok_2_w",
-      hotspot = {0, 23},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 23 }
    },
    attack_atk_fail_2_w = {
       directory = dirname .. "sword",
-      basename = "atk_fail_2_w",
-      hotspot = {0, 23},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 0, 23 }
    },
-   attack_eva_ok_e = {
+   attack_atk_ok_1_e = {
       directory = dirname .. "sword",
-      basename = "eva_ok_e",
-      hotspot = {13, 23},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 24 }
+   },
+   attack_atk_ok_1_w = {
+      directory = dirname .. "sword",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 0, 23 }
+   },
+   attack_atk_ok_2_e = {
+      directory = dirname .. "sword",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 23, 23 }
+   },
+   attack_atk_ok_2_w = {
+      directory = dirname .. "sword",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 0, 23 }
    },
    attack_eva_fail_e = {
       directory = dirname .. "sword",
-      basename = "eva_fail_e",
-      hotspot = {13, 23},
-      fps = 10
-   },
-   attack_eva_ok_w = {
-      directory = dirname .. "sword",
-      basename = "eva_ok_w",
-      hotspot = {0, 24},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 13, 23 }
    },
    attack_eva_fail_w = {
       directory = dirname .. "sword",
-      basename = "eva_fail_w",
-      hotspot = {0, 23},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 0, 23 }
    },
-   attack_die_f_w = {
+   attack_eva_ok_e = {
       directory = dirname .. "sword",
-      basename = "die_f_w",
-      hotspot = {-1, 21},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 13, 23 }
    },
-   attack_die_f_e = {
+   attack_eva_ok_w = {
       directory = dirname .. "sword",
-      basename = "die_f_e",
-      hotspot = {19, 22},
-      fps = 10
-   },
-   attack_die_b_w = {
-      directory = dirname .. "sword",
-      basename = "die_b_w",
-      hotspot = {17, 25},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 0, 24 }
    },
    attack_die_b_e = {
       directory = dirname .. "sword",
-      basename = "die_b_e",
-      hotspot = {13, 23},
-      fps = 10
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 13, 23 }
+   },
+   attack_die_b_w = {
+      directory = dirname .. "sword",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 17, 25 }
+   },
+   attack_die_f_e = {
+      directory = dirname .. "sword",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { 19, 22 }
+   },
+   attack_die_f_w = {
+      directory = dirname .. "sword",
+      fps = 10,
+      frames = 10,
+      rows = 4,
+      columns = 3,
+      hotspot = { -1, 21 }
    },
 }
 
@@ -487,14 +622,14 @@ fri_rookie = {
    max_evade = 0,
 }
 
-descriptions:new_soldier_type {
+wl.Descriptions():new_soldier_type {
    name = "frisians_soldier",
    -- TRANSLATORS: This is a worker name used in lists of workers
    descname = pgettext ("frisians_worker", "Soldier"),
    icon = dirname .. "menu.png",
    vision_range = 2,
 
-   animations = animations,
+   spritesheets = spritesheets,
 
    -- Battle attributes - initial values and per level increase
    health = {
