@@ -4,7 +4,7 @@ push_textdomain("texts")
 tips = {
    {
       -- TRANSLATORS: %s = URL to the Widelands website
-      text = (_"Our computer players are too boring? Visit our website at %s and meet other players to play online."):bformat(u("widelands.org")),
+      text = (_("Are the computer players too boring? Visit our website at %s and meet other players to play online.")):bformat(a("widelands.org", "url", "https://www.widelands.org")),
       seconds = 6
    },
 }
