@@ -1,10 +1,10 @@
 push_textdomain("world")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
 wl.Descriptions():new_critter_type{
    name = "lynx",
-   descname = _ "Lynx",
+   descname = _("Lynx"),
    icon = dirname .. "menu.png",
    animation_directory = dirname,
    programs = {
@@ -15,22 +15,31 @@ wl.Descriptions():new_critter_type{
    appetite = 10,
    carnivore = true,
 
-   animations = {
+   spritesheets = {
       idle = {
-         hotspot = { 8, 14 },
          fps = 20,
+         frames = 20,
+         rows = 5,
+         columns = 4,
+         hotspot = { 8, 14 }
       },
       eating = {
          basename = "idle", -- TODO(Nordfriese): Make animation
-         hotspot = { 8, 14 },
          fps = 20,
+         frames = 20,
+         rows = 5,
+         columns = 4,
+         hotspot = { 8, 14 }
       },
       walk = {
-         hotspot = { 11, 21 },
          fps = 20,
-         directional = true
-      }
-   }
+         frames = 20,
+         rows = 5,
+         columns = 4,
+         directional = true,
+         hotspot = { 11, 21 }
+      },
+   },
 }
 
 pop_textdomain()
