@@ -1,15 +1,16 @@
 push_textdomain("world")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
 wl.Descriptions():new_immovable_type{
    name = "bar-ruin02",
-   descname = _ "Ruin",
+   descname = _("Ruin"),
    size = "medium",
    programs = {},
+   animation_directory = dirname,
+   icon = dirname .. "menu.png",
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle.png"),
          hotspot = { 43, 43 },
       },
    }
