@@ -1,15 +1,15 @@
 push_textdomain("world")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
 wl.Descriptions():new_immovable_type{
    name = "skeleton1",
-   descname = _ "Skeleton",
+   descname = _("Skeleton"),
    size = "none",
    programs = {},
+   animation_directory = dirname,
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle.png"),
          hotspot = { 29, 36 },
       },
    }
