@@ -1,15 +1,15 @@
 push_textdomain("world")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
 wl.Descriptions():new_immovable_type{
    name = "bush3",
-   descname = _ "Bush",
+   descname = _("Bush"),
    size = "none",
    programs = {},
+   animation_directory = dirname,
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle.png"),
          hotspot = { 11, 14 },
       },
    }
