@@ -1,15 +1,16 @@
 push_textdomain("world")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
 wl.Descriptions():new_immovable_type{
    name = "standing_stone2_summer",
-   descname = _ "Standing Stone",
+   descname = _("Standing Stone"),
    size = "big",
    programs = {},
+   animation_directory = dirname,
+   icon = dirname .. "menu.png",
    animations = {
       idle = {
-         pictures = path.list_files(dirname .. "idle.png"),
          hotspot = { 20, 38 },
       },
    }
