@@ -1,6 +1,6 @@
 push_textdomain("world")
 
-dirname = path.dirname(__file__)
+local dirname = path.dirname(__file__)
 
 include(dirname .. "../terrain_affinity.lua")
 
@@ -12,7 +12,7 @@ wl.Descriptions():new_immovable_type{
    species = _("Liana Tree"),
    icon = dirname .. "../menu.png",
    size = "small",
-
+   animation_directory = dirname,
    terrain_affinity = terrain_affinity,
    programs = {
       main = {
@@ -26,7 +26,6 @@ wl.Descriptions():new_immovable_type{
    },
    spritesheets = {
       idle = {
-         directory = dirname,
          basename = "old",
          fps = 10,
          frames = 5,
