@@ -2,7 +2,7 @@ push_textdomain("world")
 
 wl.Descriptions():new_terrain_type{
    name = "summer_swamp",
-   descname = _ "Swamp",
+   descname = _("Swamp"),
    is = "unwalkable",
    valid_resources = {"resource_water"},
    default_resource = "resource_water",
